@@ -299,6 +299,7 @@ EntryDescriptor SbTreeListBox::GetEntryDescriptor(const weld::TreeIter* pEntry)
                 }
                 break;
                 case OBJ_TYPE_MODULE:
+                case OBJ_TYPE_DIALOG:
                 {
                     aName = pair.second;
                     eType = pBE->GetType();
@@ -310,12 +311,6 @@ EntryDescriptor SbTreeListBox::GetEntryDescriptor(const weld::TreeIter* pEntry)
                     eType = pBE->GetType();
                 }
                 break;
-                case OBJ_TYPE_DIALOG:
-                {
-                    aName = pair.second;
-                    eType = pBE->GetType();
-                }
-                break;
                 case OBJ_TYPE_DOCUMENT_OBJECTS:
                 case OBJ_TYPE_USERFORMS:
                 case OBJ_TYPE_NORMAL_MODULES:
@@ -338,20 +333,21 @@ EntryDescriptor SbTreeListBox::GetEntryDescriptor(const weld::TreeIter* pEntry)
         }
     }
 
-    return EntryDescriptor( aDocument, eLocation, aLibName, aLibSubName, aName, aMethodName, eType );
+    return EntryDescriptor(std::move(aDocument), eLocation, aLibName,
+                           aLibSubName, aName, aMethodName, eType);
 }
 
-ItemType SbTreeListBox::ConvertType (EntryType eType)
+SbxItemType SbTreeListBox::ConvertType (EntryType eType)
 {
     switch (eType)
     {
-        case OBJ_TYPE_DOCUMENT:  return TYPE_SHELL;
-        case OBJ_TYPE_LIBRARY:   return TYPE_LIBRARY;
-        case OBJ_TYPE_MODULE:    return TYPE_MODULE;
-        case OBJ_TYPE_DIALOG:    return TYPE_DIALOG;
-        case OBJ_TYPE_METHOD:    return TYPE_METHOD;
+        case OBJ_TYPE_DOCUMENT:  return SBX_TYPE_SHELL;
+        case OBJ_TYPE_LIBRARY:   return SBX_TYPE_LIBRARY;
+        case OBJ_TYPE_MODULE:    return SBX_TYPE_MODULE;
+        case OBJ_TYPE_DIALOG:    return SBX_TYPE_DIALOG;
+        case OBJ_TYPE_METHOD:    return SBX_TYPE_METHOD;
         default:
-            return static_cast<ItemType>(OBJ_TYPE_UNKNOWN);
+            return static_cast<SbxItemType>(OBJ_TYPE_UNKNOWN);
     }
 }
 
