@@ -101,7 +101,7 @@ rtl::Reference<OResultSet> OPreparedStatement::makeResultSet()
     closeResultSet();
 
     rtl::Reference<OResultSet> xResultSet(createResultSet());
-    m_xResultSet = uno::Reference<uno::XWeak>(xResultSet);
+    m_xResultSet = xResultSet.get();
     initializeResultSet(xResultSet.get());
     initResultSet(xResultSet.get());
     return xResultSet;
@@ -127,6 +127,11 @@ css::uno::Sequence< css::uno::Type > SAL_CALL OPreparedStatement::getTypes(  )
 
 
 Reference< XResultSetMetaData > SAL_CALL OPreparedStatement::getMetaData(  )
+{
+    return getMetaDataImpl();
+}
+
+const rtl::Reference< OResultSetMetaData > & OPreparedStatement::getMetaDataImpl(  )
 {
     ::osl::MutexGuard aGuard( m_aMutex );
     checkDisposed(OStatement_BASE::rBHelper.bDisposed);
@@ -377,7 +382,7 @@ void OPreparedStatement::initResultSet(OResultSet *pResultSet)
          m_pConnection->throwGenericSQLException(STR_INVALID_PARA_COUNT,*this);
 
     pResultSet->OpenImpl();
-    pResultSet->setMetaData(getMetaData());
+    pResultSet->setMetaData(getMetaDataImpl());
 }
 
 void SAL_CALL OPreparedStatement::acquire() noexcept
