@@ -22,8 +22,10 @@
 #include <vcl/svapp.hxx>
 #include <vcl/weld.hxx>
 #include <sfx2/dialoghelper.hxx>
+#include <sfx2/objsh.hxx>
 
 #include <strings.hrc>
+#include <svx/drawitem.hxx>
 #include <svx/xfillit0.hxx>
 #include <svx/xflgrit.hxx>
 #include <svx/colorbox.hxx>
@@ -34,6 +36,7 @@
 #include <dialmgr.hxx>
 #include <svx/dialmgr.hxx>
 #include <svx/strings.hrc>
+#include <svx/svxids.hrc>
 #include <basegfx/utils/gradienttools.hxx>
 #include <sal/log.hxx>
 
@@ -42,7 +45,7 @@ using namespace com::sun::star;
 SvxGradientTabPage::SvxGradientTabPage(weld::Container* pPage, weld::DialogController* pController, const SfxItemSet& rInAttrs)
     : SfxTabPage(pPage, pController, u"cui/ui/gradientpage.ui"_ustr, u"GradientPage"_ustr, &rInAttrs)
     , m_rOutAttrs(rInAttrs)
-    , m_pnGradientListState(nullptr)
+    , m_nGradientListState(ChangeType::NONE)
     , m_pnColorListState(nullptr)
     , m_aXFillAttr(rInAttrs.GetPool())
     , m_rXFSet(m_aXFillAttr.GetItemSet())
@@ -122,6 +125,17 @@ SvxGradientTabPage::~SvxGradientTabPage()
     m_xGradientLB.reset();
     m_xLbColorTo.reset();
     m_xLbColorFrom.reset();
+
+    if (m_nGradientListState & ChangeType::MODIFIED)
+    {
+        m_pGradientList->SetPath(AreaTabHelper::GetPalettePath());
+        m_pGradientList->Save();
+
+        // ToolBoxControls are informed:
+        SfxObjectShell* pShell = SfxObjectShell::Current();
+        if (pShell)
+            pShell->PutItem(SvxGradientListItem(m_pGradientList, SID_GRADIENT_LIST));
+    }
 }
 
 void SvxGradientTabPage::Construct()
@@ -383,7 +397,7 @@ IMPL_LINK_NOARG(SvxGradientTabPage, ClickAddHdl_Impl, weld::Button&, void)
         m_xGradientLB->SelectItem( nId + 1 );
         m_xGradientLB->Resize();
 
-        *m_pnGradientListState |= ChangeType::MODIFIED;
+        m_nGradientListState |= ChangeType::MODIFIED;
 
         ChangeGradientHdl_Impl();
     }
@@ -426,13 +440,13 @@ IMPL_LINK_NOARG(SvxGradientTabPage, ClickModifyHdl_Impl, weld::Button&, void)
     m_xGradientLB->InsertItem( nId, Image(aBitmap), aName, static_cast<sal_uInt16>(nPos) );
     m_xGradientLB->SelectItem( nId );
 
-    *m_pnGradientListState |= ChangeType::MODIFIED;
+    m_nGradientListState |= ChangeType::MODIFIED;
 }
 
 IMPL_LINK_NOARG(SvxGradientTabPage, ClickDeleteHdl_Impl, SvxPresetListBox*, void)
 {
-    sal_uInt16 nId = m_xGradientLB->GetSelectedItemId();
-    size_t nPos = m_xGradientLB->GetSelectItemPos();
+    const sal_uInt16 nId = m_xGradientLB->GetContextMenuItemId();
+    const size_t nPos = m_xGradientLB->GetItemPos(nId);
 
     if( nPos != VALUESET_ITEM_NOTFOUND )
     {
@@ -440,17 +454,19 @@ IMPL_LINK_NOARG(SvxGradientTabPage, ClickDeleteHdl_Impl, SvxPresetListBox*, void
         std::unique_ptr<weld::MessageDialog> xQueryBox(xBuilder->weld_message_dialog(u"AskDelGradientDialog"_ustr));
         if (xQueryBox->run() == RET_YES)
         {
+            const bool bDeletingSelectedItem(nId == m_xGradientLB->GetSelectedItemId());
             m_pGradientList->Remove(nPos);
             m_xGradientLB->RemoveItem( nId );
-            nId = m_xGradientLB->GetItemId( 0 );
-            m_xGradientLB->SelectItem( nId );
+            if (bDeletingSelectedItem)
+            {
+                m_xGradientLB->SelectItem(m_xGradientLB->GetItemId(/*Position=*/0));
+                m_aCtlPreview.Invalidate();
+            }
             m_xGradientLB->Resize();
 
-            m_aCtlPreview.Invalidate();
-
             ChangeGradientHdl_Impl();
 
-            *m_pnGradientListState |= ChangeType::MODIFIED;
+            m_nGradientListState |= ChangeType::MODIFIED;
         }
     }
     // determine button state
@@ -460,8 +476,8 @@ IMPL_LINK_NOARG(SvxGradientTabPage, ClickDeleteHdl_Impl, SvxPresetListBox*, void
 
 IMPL_LINK_NOARG(SvxGradientTabPage, ClickRenameHdl_Impl, SvxPresetListBox*, void)
 {
-    sal_uInt16 nId = m_xGradientLB->GetSelectedItemId();
-    size_t nPos = m_xGradientLB->GetSelectItemPos();
+    const sal_uInt16 nId = m_xGradientLB->GetContextMenuItemId();
+    const size_t nPos = m_xGradientLB->GetItemPos(nId);
 
     if ( nPos == VALUESET_ITEM_NOTFOUND )
         return;
@@ -485,9 +501,8 @@ IMPL_LINK_NOARG(SvxGradientTabPage, ClickRenameHdl_Impl, SvxPresetListBox*, void
             m_pGradientList->GetGradient(nPos)->SetName(aName);
 
             m_xGradientLB->SetItemText( nId, aName );
-            m_xGradientLB->SelectItem( nId );
 
-            *m_pnGradientListState |= ChangeType::MODIFIED;
+            m_nGradientListState |= ChangeType::MODIFIED;
         }
         else
         {
@@ -611,14 +626,6 @@ void SvxGradientTabPage::SetControlState_Impl( css::awt::GradientStyle eXGS )
             break;
 
         case css::awt::GradientStyle_ELLIPTICAL:
-            m_xFtCenter->set_sensitive(true);
-            m_xMtrCenterX->set_sensitive(true);
-            m_xMtrCenterY->set_sensitive(true);
-            m_xFtAngle->set_sensitive(true);
-            m_xMtrAngle->set_sensitive(true);
-            m_xSliderAngle->set_sensitive(true);
-            break;
-
         case css::awt::GradientStyle_SQUARE:
         case css::awt::GradientStyle_RECT:
             m_xFtCenter->set_sensitive(true);
@@ -628,6 +635,7 @@ void SvxGradientTabPage::SetControlState_Impl( css::awt::GradientStyle eXGS )
             m_xMtrAngle->set_sensitive(true);
             m_xSliderAngle->set_sensitive(true);
             break;
+
         default:
             break;
     }
