@@ -56,9 +56,7 @@ namespace pcr
     using namespace ::com::sun::star::uno;
     using namespace ::com::sun::star::lang;
     using namespace ::com::sun::star::beans;
-    using namespace ::com::sun::star::xforms;
     using namespace ::com::sun::star::xsd;
-    using namespace ::com::sun::star::script;
     using namespace ::com::sun::star::inspection;
 
     using ::com::sun::star::beans::PropertyAttribute::MAYBEVOID;
@@ -79,13 +77,13 @@ namespace pcr
 
     OUString XSDValidationPropertyHandler::getImplementationName(  )
     {
-        return "com.sun.star.comp.extensions.XSDValidationPropertyHandler";
+        return u"com.sun.star.comp.extensions.XSDValidationPropertyHandler"_ustr;
     }
 
 
     Sequence< OUString > XSDValidationPropertyHandler::getSupportedServiceNames(  )
     {
-        return{ "com.sun.star.form.inspection.XSDValidationPropertyHandler" };
+        return{ u"com.sun.star.form.inspection.XSDValidationPropertyHandler"_ustr };
     }
 
 
