@@ -17,8 +17,8 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#ifndef _OSL_MODULE_CONST_H_
-#define _OSL_MODULE_CONST_H_
+#ifndef INCLUDED_SAL_QA_OSL_MODULE_OSL_MODULE_CONST_H
+#define INCLUDED_SAL_QA_OSL_MODULE_OSL_MODULE_CONST_H
 
 #include <sal/types.h>
 #include <rtl/ustring.hxx>
@@ -29,21 +29,18 @@
 #include <cppunit/extensions/HelperMacros.h>
 #include <cppunit/plugin/TestPlugIn.h>
 
-#if ( defined UNX )                      //Unix
+#if   defined(UNX)                      // Unix
 #   include <unistd.h>
-#endif
-#if ( defined WNT )                     // Windows
+#elif defined(_WIN32)                   // Windows
 #   include <io.h>
 #endif
 
 #   define FILE_PREFIX          "file:///"
 
-//------------------------------------------------------------------------
 // function pointer type.
-//------------------------------------------------------------------------
+
 typedef sal_Bool (* FuncPtr )( sal_Bool );
 
-
-#endif /* _OSL_MODULE_CONST_H_ */
+#endif // INCLUDED_SAL_QA_OSL_MODULE_OSL_MODULE_CONST_H
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
