@@ -76,14 +76,16 @@ ScXMLCellImportPropertyMapper::~ScXMLCellImportPropertyMapper()
 {
 }
 
-void ScXMLCellImportPropertyMapper::finished(::std::vector< XMLPropertyState >& rProperties, sal_Int32 nStartIndex, sal_Int32 nEndIndex ) const
+void ScXMLCellImportPropertyMapper::finished(std::vector<XMLPropertyState>& rProperties,
+                                             sal_Int32 nStartIndex, sal_Int32 nEndIndex,
+                                             const sal_uInt32 nPropType) const
 {
     static const sal_Int16 aPaddingCTF[4] = { CTF_SC_LEFTPADDING, CTF_SC_RIGHTPADDING,
                                             CTF_SC_TOPPADDING, CTF_SC_BOTTOMPADDING };
     static const sal_Int16 aBorderCTF[4] = { CTF_SC_LEFTBORDER, CTF_SC_RIGHTBORDER,
                                             CTF_SC_TOPBORDER, CTF_SC_BOTTOMBORDER };
 
-    SvXMLImportPropertyMapper::finished(rProperties, nStartIndex, nEndIndex);
+    SvXMLImportPropertyMapper::finished(rProperties, nStartIndex, nEndIndex, nPropType);
     XMLPropertyState* pAllPaddingProperty(nullptr);
     XMLPropertyState* pPadding[4] = { nullptr, nullptr, nullptr, nullptr };
     XMLPropertyState* pNewPadding[4] = { nullptr, nullptr, nullptr, nullptr };
@@ -217,9 +219,11 @@ ScXMLRowImportPropertyMapper::~ScXMLRowImportPropertyMapper()
 {
 }
 
-void ScXMLRowImportPropertyMapper::finished(::std::vector< XMLPropertyState >& rProperties, sal_Int32 nStartIndex, sal_Int32 nEndIndex ) const
+void ScXMLRowImportPropertyMapper::finished(std::vector<XMLPropertyState>& rProperties,
+                                            sal_Int32 nStartIndex, sal_Int32 nEndIndex,
+                                            const sal_uInt32 nPropType) const
 {
-    SvXMLImportPropertyMapper::finished(rProperties, nStartIndex, nEndIndex);
+    SvXMLImportPropertyMapper::finished(rProperties, nStartIndex, nEndIndex, nPropType);
     XMLPropertyState* pHeight(nullptr);
     XMLPropertyState* pOptimalHeight(nullptr);
     XMLPropertyState* pPageBreak(nullptr);
@@ -400,6 +404,7 @@ ScCondFormatEntry* ScXMLMapContext::CreateConditionEntry()
 
     ScConditionMode eMode = ScConditionEntry::GetModeFromApi(aParseResult.meOperator);
     ScDocument* pDoc = GetScImport().GetDocument();
+    assert(pDoc);
 
     ScCondFormatEntry* pEntry =  new ScCondFormatEntry(eMode, aParseResult.maOperand1, aParseResult.maOperand2, *pDoc, ScAddress(), msApplyStyle,
                                                     OUString(), OUString(), eGrammar, eGrammar);
@@ -488,6 +493,9 @@ void XMLTableStyleContext::ApplyCondFormat( const uno::Sequence<table::CellRange
     }
 
     ScDocument* pDoc = GetScImport().GetDocument();
+    if (!pDoc)
+        return;
+
     SCTAB nTab = GetScImport().GetTables().GetCurrentSheet();
     ScConditionalFormatList* pFormatList = pDoc->GetCondFormList(nTab);
     auto itr = std::find_if(pFormatList->begin(), pFormatList->end(),
