@@ -50,7 +50,7 @@ static bool isLOKMobilePhone()
     return pCurrent && pCurrent->isLOKMobilePhone();
 }
 
-ScCondFrmtEntry::ScCondFrmtEntry(ScCondFormatList* pParent, ScDocument* pDoc, const ScAddress& rPos)
+ScCondFrmtEntry::ScCondFrmtEntry(ScCondFormatList* pParent, ScDocument& rDoc, const ScAddress& rPos)
     : mpParent(pParent)
     , mxBuilder(Application::CreateBuilder(pParent->GetContainer(), isLOKMobilePhone()?u"modules/scalc/ui/conditionalentrymobile.ui"_ustr:u"modules/scalc/ui/conditionalentry.ui"_ustr))
     , mxBorder(mxBuilder->weld_widget(u"border"_ustr))
@@ -60,7 +60,7 @@ ScCondFrmtEntry::ScCondFrmtEntry(ScCondFormatList* pParent, ScDocument* pDoc, co
     , mbActive(false)
     , maStrCondition(ScResId(SCSTR_CONDITION))
     , mxLbType(mxBuilder->weld_combo_box(u"type"_ustr))
-    , mpDoc(pDoc)
+    , mrDoc(rDoc)
     , maPos(rPos)
 {
     mxLbType->set_size_request(CommonWidgetWidth, -1);
@@ -110,17 +110,18 @@ void ScCondFrmtEntry::Deselect()
 
 //condition
 
-namespace {
+namespace
+{
 
-void FillStyleListBox( const ScDocument* pDoc, weld::ComboBox& rLbStyle )
+void FillStyleListBox(const ScDocument* pDoc, weld::ComboBox& rLbStyle)
 {
     std::set<OUString> aStyleNames;
-    SfxStyleSheetIterator aStyleIter( pDoc->GetStyleSheetPool(), SfxStyleFamily::Para );
-    for ( SfxStyleSheetBase* pStyle = aStyleIter.First(); pStyle; pStyle = aStyleIter.Next() )
+    SfxStyleSheetIterator aStyleIter(pDoc->GetStyleSheetPool(), SfxStyleFamily::Para);
+    for (SfxStyleSheetBase* pStyle = aStyleIter.First(); pStyle; pStyle = aStyleIter.Next())
     {
         aStyleNames.insert(pStyle->GetName());
     }
-    for(const auto& rStyleName : aStyleNames)
+    for (const auto& rStyleName : aStyleNames)
     {
         rLbStyle.append_text(rStyleName);
     }
@@ -128,36 +129,35 @@ void FillStyleListBox( const ScDocument* pDoc, weld::ComboBox& rLbStyle )
 
 }
 
-const ScConditionMode ScConditionFrmtEntry::mpEntryToCond[ScConditionFrmtEntry::NUM_COND_ENTRIES] = {
-    ScConditionMode::Equal,
-    ScConditionMode::Less,
-    ScConditionMode::Greater,
-    ScConditionMode::EqLess,
-    ScConditionMode::EqGreater,
-    ScConditionMode::NotEqual,
-    ScConditionMode::Between,
-    ScConditionMode::NotBetween,
-    ScConditionMode::Duplicate,
-    ScConditionMode::NotDuplicate,
-    ScConditionMode::Top10,
-    ScConditionMode::Bottom10,
-    ScConditionMode::TopPercent,
-    ScConditionMode::BottomPercent,
-    ScConditionMode::AboveAverage,
-    ScConditionMode::BelowAverage,
-    ScConditionMode::AboveEqualAverage,
-    ScConditionMode::BelowEqualAverage,
-    ScConditionMode::Error,
-    ScConditionMode::NoError,
-    ScConditionMode::BeginsWith,
-    ScConditionMode::EndsWith,
-    ScConditionMode::ContainsText,
-    ScConditionMode::NotContainsText
-};
+const ScConditionMode ScConditionFrmtEntry::mpEntryToCond[ScConditionFrmtEntry::NUM_COND_ENTRIES]
+    = { ScConditionMode::Equal,
+        ScConditionMode::Less,
+        ScConditionMode::Greater,
+        ScConditionMode::EqLess,
+        ScConditionMode::EqGreater,
+        ScConditionMode::NotEqual,
+        ScConditionMode::Between,
+        ScConditionMode::NotBetween,
+        ScConditionMode::Duplicate,
+        ScConditionMode::NotDuplicate,
+        ScConditionMode::Top10,
+        ScConditionMode::Bottom10,
+        ScConditionMode::TopPercent,
+        ScConditionMode::BottomPercent,
+        ScConditionMode::AboveAverage,
+        ScConditionMode::BelowAverage,
+        ScConditionMode::AboveEqualAverage,
+        ScConditionMode::BelowEqualAverage,
+        ScConditionMode::Error,
+        ScConditionMode::NoError,
+        ScConditionMode::BeginsWith,
+        ScConditionMode::EndsWith,
+        ScConditionMode::ContainsText,
+        ScConditionMode::NotContainsText };
 
-ScConditionFrmtEntry::ScConditionFrmtEntry(ScCondFormatList* pParent, ScDocument* pDoc, ScCondFormatDlg* pDialogParent,
+ScConditionFrmtEntry::ScConditionFrmtEntry(ScCondFormatList* pParent, ScDocument& rDoc, ScCondFormatDlg* pDialogParent,
         const ScAddress& rPos, const ScCondFormatEntry* pFormatEntry)
-    : ScCondFrmtEntry(pParent, pDoc, rPos)
+    : ScCondFrmtEntry(pParent, rDoc, rPos)
     , mxLbCondType(mxBuilder->weld_combo_box(u"typeis"_ustr))
     , mxEdVal1(new formula::RefEdit(mxBuilder->weld_entry(u"val1"_ustr)))
     , mxEdVal2(new formula::RefEdit(mxBuilder->weld_entry(u"val2"_ustr)))
@@ -176,7 +176,7 @@ ScConditionFrmtEntry::ScConditionFrmtEntry(ScCondFormatList* pParent, ScDocument
 
     Init(pDialogParent);
 
-    StartListening(*pDoc->GetStyleSheetPool(), DuplicateHandling::Prevent);
+    StartListening(*rDoc.GetStyleSheetPool(), DuplicateHandling::Prevent);
 
     if(pFormatEntry)
     {
@@ -228,7 +228,7 @@ void ScConditionFrmtEntry::Init(ScCondFormatDlg* pDialogParent)
     mxEdVal1->SetModifyHdl( LINK( this, ScConditionFrmtEntry, OnEdChanged ) );
     mxEdVal2->SetModifyHdl( LINK( this, ScConditionFrmtEntry, OnEdChanged ) );
 
-    FillStyleListBox( mpDoc, *mxLbStyle );
+    FillStyleListBox(&mrDoc, *mxLbStyle);
     mxLbStyle->connect_changed( LINK( this, ScConditionFrmtEntry, StyleSelectHdl ) );
 
     mxLbCondType->connect_changed( LINK( this, ScConditionFrmtEntry, ConditionTypeSelectHdl ) );
@@ -248,7 +248,7 @@ ScFormatEntry* ScConditionFrmtEntry::createConditionEntry() const
         }
     }
 
-    ScFormatEntry* pEntry = new ScCondFormatEntry(eMode, aExpr1, aExpr2, *mpDoc, maPos, mxLbStyle->get_active_text());
+    ScFormatEntry* pEntry = new ScCondFormatEntry(eMode, aExpr1, aExpr2, mrDoc, maPos, mxLbStyle->get_active_text());
     return pEntry;
 }
 
@@ -257,18 +257,20 @@ IMPL_LINK(ScConditionFrmtEntry, OnEdChanged, formula::RefEdit&, rRefEdit, void)
     weld::Entry& rEdit = *rRefEdit.GetWidget();
     OUString aFormula = rEdit.get_text();
 
-    if( aFormula.isEmpty() )
+    if (aFormula.isEmpty())
     {
         mxFtVal->set_label(ScResId(STR_ENTER_VALUE));
         return;
     }
 
-    ScCompiler aComp( *mpDoc, maPos, mpDoc->GetGrammar() );
-    aComp.SetExtendedErrorDetection( ScCompiler::ExtendedErrorDetection::EXTENDED_ERROR_DETECTION_NAME_BREAK);
+    ScCompiler aComp(mrDoc, maPos, mrDoc.GetGrammar());
+    aComp.SetExtendedErrorDetection(
+        ScCompiler::ExtendedErrorDetection::EXTENDED_ERROR_DETECTION_NAME_BREAK);
     std::unique_ptr<ScTokenArray> ta(aComp.CompileString(aFormula));
 
     // Error, warn the user if it is not an unknown name.
-    if (ta->GetCodeError() != FormulaError::NoName && (ta->GetCodeError() != FormulaError::NONE || ta->GetLen() == 0))
+    if (ta->GetCodeError() != FormulaError::NoName
+        && (ta->GetCodeError() != FormulaError::NONE || ta->GetLen() == 0))
     {
         rEdit.set_message_type(weld::EntryMessageType::Error);
         mxFtVal->set_label(ScResId(STR_VALID_DEFERROR));
@@ -296,7 +298,7 @@ IMPL_LINK(ScConditionFrmtEntry, OnEdChanged, formula::RefEdit&, rRefEdit, void)
     }
 
     rEdit.set_message_type(weld::EntryMessageType::Normal);
-    mxFtVal->set_label(u""_ustr);
+    mxFtVal->set_label("");
 }
 
 void ScConditionFrmtEntry::Select()
@@ -410,7 +412,8 @@ void ScConditionFrmtEntry::SetInactive()
     Deselect();
 }
 
-namespace {
+namespace
+{
 
 void UpdateStyleList(weld::ComboBox& rLbStyle, const ScDocument* pDoc)
 {
@@ -428,21 +431,23 @@ void ScConditionFrmtEntry::Notify(SfxBroadcaster&, const SfxHint& rHint)
     if(rHint.GetId() == SfxHintId::StyleSheetModified || rHint.GetId() == SfxHintId::StyleSheetModifiedExtended)
     {
         if(!mbIsInStyleCreate)
-            UpdateStyleList(*mxLbStyle, mpDoc);
+            UpdateStyleList(*mxLbStyle, &mrDoc);
     }
 }
 
-namespace {
+namespace
+{
 
-void StyleSelect(weld::Window* pDialogParent, weld::ComboBox& rLbStyle, const ScDocument* pDoc, SvxFontPrevWindow& rWdPreview)
+void StyleSelect(weld::Window* pDialogParent, weld::ComboBox& rLbStyle, const ScDocument* pDoc,
+                 SvxFontPrevWindow& rWdPreview)
 {
     if (rLbStyle.get_active() == 0)
     {
         // call new style dialog
-        SfxUInt16Item aFamilyItem( SID_STYLE_FAMILY, sal_uInt16(SfxStyleFamily::Para) );
-        SfxStringItem aRefItem( SID_STYLE_REFERENCE, ScResId(STR_STYLENAME_STANDARD) );
+        SfxUInt16Item aFamilyItem(SID_STYLE_FAMILY, sal_uInt16(SfxStyleFamily::Para));
+        SfxStringItem aRefItem(SID_STYLE_REFERENCE, ScResId(STR_STYLENAME_STANDARD));
         css::uno::Any aAny(pDialogParent->GetXWindow());
-        SfxUnoAnyItem aDialogParent( SID_DIALOG_PARENT, aAny );
+        SfxUnoAnyItem aDialogParent(SID_DIALOG_PARENT, aAny);
 
         // unlock the dispatcher so SID_STYLE_NEW can be executed
         // (SetDispatcherLock would affect all Calc documents)
@@ -456,31 +461,32 @@ void StyleSelect(weld::Window* pDialogParent, weld::ComboBox& rLbStyle, const Sc
 
                 // Execute the "new style" slot, complete with undo and all necessary updates.
                 // The return value (SfxUInt16Item) is ignored, look for new styles instead.
-                pDisp->ExecuteList(SID_STYLE_NEW,
-                    SfxCallMode::SYNCHRON | SfxCallMode::RECORD,
-                    { &aFamilyItem, &aRefItem }, { &aDialogParent });
+                pDisp->ExecuteList(SID_STYLE_NEW, SfxCallMode::SYNCHRON | SfxCallMode::RECORD,
+                                   { &aFamilyItem, &aRefItem }, { &aDialogParent });
 
                 if (bLocked)
                     pDisp->Lock(true);
 
                 // Find the new style and add it into the style list boxes
-                SfxStyleSheetIterator aStyleIter( pDoc->GetStyleSheetPool(), SfxStyleFamily::Para );
+                SfxStyleSheetIterator aStyleIter(pDoc->GetStyleSheetPool(), SfxStyleFamily::Para);
                 bool bFound = false;
-                for ( SfxStyleSheetBase* pStyle = aStyleIter.First(); pStyle && !bFound; pStyle = aStyleIter.Next() )
+                for (SfxStyleSheetBase* pStyle = aStyleIter.First(); pStyle && !bFound;
+                     pStyle = aStyleIter.Next())
                 {
                     const OUString& aName = pStyle->GetName();
-                    if (rLbStyle.find_text(aName) == -1)    // all lists contain the same entries
+                    if (rLbStyle.find_text(aName) == -1) // all lists contain the same entries
                     {
-                        for( sal_Int32 i = 1, n = rLbStyle.get_count(); i <= n && !bFound; ++i)
+                        for (sal_Int32 i = 1, n = rLbStyle.get_count(); i <= n && !bFound; ++i)
                         {
-                            OUString aStyleName = ScGlobal::getCharClass().uppercase(rLbStyle.get_text(i));
-                            if( i == n )
+                            OUString aStyleName
+                                = ScGlobal::getCharClass().uppercase(rLbStyle.get_text(i));
+                            if (i == n)
                             {
                                 rLbStyle.append_text(aName);
                                 rLbStyle.set_active_text(aName);
                                 bFound = true;
                             }
-                            else if( aStyleName > ScGlobal::getCharClass().uppercase(aName) )
+                            else if (aStyleName > ScGlobal::getCharClass().uppercase(aName))
                             {
                                 rLbStyle.insert_text(i, aName);
                                 rLbStyle.set_active_text(aName);
@@ -494,8 +500,9 @@ void StyleSelect(weld::Window* pDialogParent, weld::ComboBox& rLbStyle, const Sc
     }
 
     OUString aStyleName = rLbStyle.get_active_text();
-    SfxStyleSheetBase* pStyleSheet = pDoc->GetStyleSheetPool()->Find( aStyleName, SfxStyleFamily::Para );
-    if(pStyleSheet)
+    SfxStyleSheetBase* pStyleSheet
+        = pDoc->GetStyleSheetPool()->Find(aStyleName, SfxStyleFamily::Para);
+    if (pStyleSheet)
     {
         const SfxItemSet& rSet = pStyleSheet->GetItemSet();
         rWdPreview.SetFromItemSet(rSet, false);
@@ -507,14 +514,14 @@ void StyleSelect(weld::Window* pDialogParent, weld::ComboBox& rLbStyle, const Sc
 IMPL_LINK_NOARG(ScConditionFrmtEntry, StyleSelectHdl, weld::ComboBox&, void)
 {
     mbIsInStyleCreate = true;
-    StyleSelect(mpParent->GetFrameWeld(), *mxLbStyle, mpDoc, maWdPreview);
+    StyleSelect(mpParent->GetFrameWeld(), *mxLbStyle, &mrDoc, maWdPreview);
     mbIsInStyleCreate = false;
 }
 
 // formula
 
-ScFormulaFrmtEntry::ScFormulaFrmtEntry(ScCondFormatList* pParent, ScDocument* pDoc, ScCondFormatDlg* pDialogParent, const ScAddress& rPos, const ScCondFormatEntry* pFormat)
-    : ScCondFrmtEntry(pParent, pDoc, rPos)
+ScFormulaFrmtEntry::ScFormulaFrmtEntry(ScCondFormatList* pParent, ScDocument& rDoc, ScCondFormatDlg* pDialogParent, const ScAddress& rPos, const ScCondFormatEntry* pFormat)
+    : ScCondFrmtEntry(pParent, rDoc, rPos)
     , mxFtStyle(mxBuilder->weld_label(u"styleft"_ustr))
     , mxLbStyle(mxBuilder->weld_combo_box(u"style"_ustr))
     , mxWdPreviewWin(mxBuilder->weld_widget(u"previewwin"_ustr))
@@ -530,7 +537,7 @@ ScFormulaFrmtEntry::ScFormulaFrmtEntry(ScCondFormatList* pParent, ScDocument* pD
 
     if(pFormat)
     {
-        mxEdFormula->SetText(pFormat->GetExpression(rPos, 0, 0, pDoc->GetGrammar()));
+        mxEdFormula->SetText(pFormat->GetExpression(rPos, 0, 0, rDoc.GetGrammar()));
         mxLbStyle->set_active_text(pFormat->GetStyle());
     }
     else
@@ -549,13 +556,13 @@ void ScFormulaFrmtEntry::Init(ScCondFormatDlg* pDialogParent)
 {
     mxEdFormula->SetGetFocusHdl( LINK( pDialogParent, ScCondFormatDlg, RangeGetFocusHdl ) );
 
-    FillStyleListBox( mpDoc, *mxLbStyle );
+    FillStyleListBox(&mrDoc, *mxLbStyle);
     mxLbStyle->connect_changed( LINK( this, ScFormulaFrmtEntry, StyleSelectHdl ) );
 }
 
 IMPL_LINK_NOARG(ScFormulaFrmtEntry, StyleSelectHdl, weld::ComboBox&, void)
 {
-    StyleSelect(mpParent->GetFrameWeld(), *mxLbStyle, mpDoc, maWdPreview);
+    StyleSelect(mpParent->GetFrameWeld(), *mxLbStyle, &mrDoc, maWdPreview);
 }
 
 ScFormatEntry* ScFormulaFrmtEntry::createFormulaEntry() const
@@ -564,7 +571,7 @@ ScFormatEntry* ScFormulaFrmtEntry::createFormulaEntry() const
     if(aFormula.isEmpty())
         return nullptr;
 
-    ScFormatEntry* pEntry = new ScCondFormatEntry(ScConditionMode::Direct, aFormula, OUString(), *mpDoc, maPos, mxLbStyle->get_active_text());
+    ScFormatEntry* pEntry = new ScCondFormatEntry(ScConditionMode::Direct, aFormula, OUString(), mrDoc, maPos, mxLbStyle->get_active_text());
     return pEntry;
 }
 
@@ -602,12 +609,10 @@ void ScFormulaFrmtEntry::SetInactive()
 
 namespace {
 
-OUString convertNumberToString(double nVal, const ScDocument* pDoc)
+OUString convertNumberToString(double nVal, const ScDocument& rDoc)
 {
-    SvNumberFormatter* pNumberFormatter = pDoc->GetFormatTable();
-    OUString aText;
-    pNumberFormatter->GetInputLineString(nVal, 0, aText);
-    return aText;
+    SvNumberFormatter* pNumberFormatter = rDoc.GetFormatTable();
+    return pNumberFormatter->GetInputLineString(nVal, 0);
 }
 
 const struct
@@ -668,7 +673,7 @@ void removeType(weld::ComboBox& rListBox, ScColorScaleEntryType eType)
         rListBox.remove(nPos);
 }
 
-void SetColorScaleEntryTypes( const ScColorScaleEntry& rEntry, weld::ComboBox& rLbType, weld::Entry& rEdit, ColorListBox& rLbCol, const ScDocument* pDoc )
+void SetColorScaleEntryTypes( const ScColorScaleEntry& rEntry, weld::ComboBox& rLbType, weld::Entry& rEdit, ColorListBox& rLbCol, const ScDocument& rDoc )
 {
     // entry Automatic is not available for color scales
     assert(rEntry.GetType() > COLORSCALE_AUTO);
@@ -683,7 +688,7 @@ void SetColorScaleEntryTypes( const ScColorScaleEntry& rEntry, weld::ComboBox& r
         case COLORSCALE_PERCENT:
             {
                 double nVal = rEntry.GetValue();
-                rEdit.set_text(convertNumberToString(nVal, pDoc));
+                rEdit.set_text(convertNumberToString(nVal, rDoc));
             }
             break;
         case COLORSCALE_FORMULA:
@@ -697,7 +702,7 @@ void SetColorScaleEntryTypes( const ScColorScaleEntry& rEntry, weld::ComboBox& r
 }
 
 void SetColorScaleEntry(ScColorScaleEntry* pEntry, const weld::ComboBox& rType, const weld::Entry& rValue,
-                        ScDocument* pDoc, const ScAddress& rPos)
+                        ScDocument& rDoc, const ScAddress& rPos)
 {
     ScColorScaleEntryType eType = getSelectedType(rType);
 
@@ -714,24 +719,24 @@ void SetColorScaleEntry(ScColorScaleEntry* pEntry, const weld::ComboBox& rType,
             {
                 sal_uInt32 nIndex = 0;
                 double nVal = 0;
-                SvNumberFormatter* pNumberFormatter = pDoc->GetFormatTable();
+                SvNumberFormatter* pNumberFormatter = rDoc.GetFormatTable();
                 (void)pNumberFormatter->IsNumberFormat(rValue.get_text(), nIndex, nVal);
                 pEntry->SetValue(nVal);
             }
             break;
         case COLORSCALE_FORMULA:
-            pEntry->SetFormula(rValue.get_text(), *pDoc, rPos);
+            pEntry->SetFormula(rValue.get_text(), rDoc, rPos);
             break;
         default:
             break;
     }
 }
 
-ScColorScaleEntry* createColorScaleEntry( const weld::ComboBox& rType, const ColorListBox& rColor, const weld::Entry& rValue, ScDocument* pDoc, const ScAddress& rPos )
+ScColorScaleEntry* createColorScaleEntry( const weld::ComboBox& rType, const ColorListBox& rColor, const weld::Entry& rValue, ScDocument& rDoc, const ScAddress& rPos )
 {
     ScColorScaleEntry* pEntry = new ScColorScaleEntry();
 
-    SetColorScaleEntry(pEntry, rType, rValue, pDoc, rPos);
+    SetColorScaleEntry(pEntry, rType, rValue, rDoc, rPos);
     Color aColor = rColor.GetSelectEntryColor();
     pEntry->SetColor(aColor);
     return pEntry;
@@ -739,8 +744,8 @@ ScColorScaleEntry* createColorScaleEntry( const weld::ComboBox& rType, const Col
 
 }
 
-ScColorScale2FrmtEntry::ScColorScale2FrmtEntry(ScCondFormatList* pParent, ScDocument* pDoc, const ScAddress& rPos, const ScColorScaleFormat* pFormat)
-    : ScCondFrmtEntry(pParent, pDoc, rPos)
+ScColorScale2FrmtEntry::ScColorScale2FrmtEntry(ScCondFormatList* pParent, ScDocument& rDoc, const ScAddress& rPos, const ScColorScaleFormat* pFormat)
+    : ScCondFrmtEntry(pParent, rDoc, rPos)
     , mxLbColorFormat(mxBuilder->weld_combo_box(u"colorformat"_ustr))
     , mxLbEntryTypeMin(mxBuilder->weld_combo_box(u"colscalemin"_ustr))
     , mxLbEntryTypeMax(mxBuilder->weld_combo_box(u"colscalemax"_ustr))
@@ -773,9 +778,9 @@ ScColorScale2FrmtEntry::ScColorScale2FrmtEntry(ScCondFormatList* pParent, ScDocu
     if(pFormat)
     {
         ScColorScaleEntries::const_iterator itr = pFormat->begin();
-        SetColorScaleEntryTypes(*itr[0], *mxLbEntryTypeMin, *mxEdMin, *mxLbColMin, pDoc);
+        SetColorScaleEntryTypes(*itr[0], *mxLbEntryTypeMin, *mxEdMin, *mxLbColMin, rDoc);
         ++itr;
-        SetColorScaleEntryTypes(*itr[0], *mxLbEntryTypeMax, *mxEdMax, *mxLbColMax, pDoc);
+        SetColorScaleEntryTypes(*itr[0], *mxLbEntryTypeMax, *mxEdMax, *mxLbColMax, rDoc);
     }
     else
     {
@@ -803,9 +808,9 @@ void ScColorScale2FrmtEntry::Init()
 
 ScFormatEntry* ScColorScale2FrmtEntry::createColorscaleEntry() const
 {
-    ScColorScaleFormat* pColorScale = new ScColorScaleFormat(mpDoc);
-    pColorScale->AddEntry(createColorScaleEntry(*mxLbEntryTypeMin, *mxLbColMin, *mxEdMin, mpDoc, maPos));
-    pColorScale->AddEntry(createColorScaleEntry(*mxLbEntryTypeMax, *mxLbColMax, *mxEdMax, mpDoc, maPos));
+    ScColorScaleFormat* pColorScale = new ScColorScaleFormat(&mrDoc);
+    pColorScale->AddEntry(createColorScaleEntry(*mxLbEntryTypeMin, *mxLbColMin, *mxEdMin, mrDoc, maPos));
+    pColorScale->AddEntry(createColorScaleEntry(*mxLbEntryTypeMax, *mxLbColMax, *mxEdMax, mrDoc, maPos));
     return pColorScale;
 }
 
@@ -874,8 +879,8 @@ IMPL_LINK( ScColorScale2FrmtEntry, EntryTypeHdl, weld::ComboBox&, rBox, void )
         pEd->set_sensitive(false);
 }
 
-ScColorScale3FrmtEntry::ScColorScale3FrmtEntry(ScCondFormatList* pParent, ScDocument* pDoc, const ScAddress& rPos, const ScColorScaleFormat* pFormat)
-    : ScCondFrmtEntry(pParent, pDoc, rPos)
+ScColorScale3FrmtEntry::ScColorScale3FrmtEntry(ScCondFormatList* pParent, ScDocument& rDoc, const ScAddress& rPos, const ScColorScaleFormat* pFormat)
+    : ScCondFrmtEntry(pParent, rDoc, rPos)
     , mxLbColorFormat(mxBuilder->weld_combo_box(u"colorformat"_ustr))
     , mxLbEntryTypeMin(mxBuilder->weld_combo_box(u"colscalemin"_ustr))
     , mxLbEntryTypeMiddle(mxBuilder->weld_combo_box(u"colscalemiddle"_ustr))
@@ -913,12 +918,12 @@ ScColorScale3FrmtEntry::ScColorScale3FrmtEntry(ScCondFormatList* pParent, ScDocu
     if(pFormat)
     {
         ScColorScaleEntries::const_iterator itr = pFormat->begin();
-        SetColorScaleEntryTypes(*itr[0], *mxLbEntryTypeMin, *mxEdMin, *mxLbColMin, pDoc);
+        SetColorScaleEntryTypes(*itr[0], *mxLbEntryTypeMin, *mxEdMin, *mxLbColMin, rDoc);
         assert(pFormat->size() == 3);
         ++itr;
-        SetColorScaleEntryTypes(*itr[0], *mxLbEntryTypeMiddle, *mxEdMiddle, *mxLbColMiddle, pDoc);
+        SetColorScaleEntryTypes(*itr[0], *mxLbEntryTypeMiddle, *mxEdMiddle, *mxLbColMiddle, rDoc);
         ++itr;
-        SetColorScaleEntryTypes(*itr[0], *mxLbEntryTypeMax, *mxEdMax, *mxLbColMax, pDoc);
+        SetColorScaleEntryTypes(*itr[0], *mxLbEntryTypeMax, *mxEdMax, *mxLbColMax, rDoc);
     }
     else
     {
@@ -951,11 +956,11 @@ void ScColorScale3FrmtEntry::Init()
 
 ScFormatEntry* ScColorScale3FrmtEntry::createColorscaleEntry() const
 {
-    ScColorScaleFormat* pColorScale = new ScColorScaleFormat(mpDoc);
-    pColorScale->AddEntry(createColorScaleEntry(*mxLbEntryTypeMin, *mxLbColMin, *mxEdMin, mpDoc, maPos));
+    ScColorScaleFormat* pColorScale = new ScColorScaleFormat(&mrDoc);
+    pColorScale->AddEntry(createColorScaleEntry(*mxLbEntryTypeMin, *mxLbColMin, *mxEdMin, mrDoc, maPos));
     if (mxLbColorFormat->get_active() == 1)
-        pColorScale->AddEntry(createColorScaleEntry(*mxLbEntryTypeMiddle, *mxLbColMiddle, *mxEdMiddle, mpDoc, maPos));
-    pColorScale->AddEntry(createColorScaleEntry(*mxLbEntryTypeMax, *mxLbColMax, *mxEdMax, mpDoc, maPos));
+        pColorScale->AddEntry(createColorScaleEntry(*mxLbEntryTypeMiddle, *mxLbColMiddle, *mxEdMiddle, mrDoc, maPos));
+    pColorScale->AddEntry(createColorScaleEntry(*mxLbEntryTypeMax, *mxLbColMax, *mxEdMax, mrDoc, maPos));
     return pColorScale;
 }
 
@@ -1059,7 +1064,7 @@ IMPL_LINK_NOARG(ScConditionFrmtEntry, ConditionTypeSelectHdl, weld::ComboBox&, v
 
 namespace {
 
-void SetDataBarEntryTypes( const ScColorScaleEntry& rEntry, weld::ComboBox& rLbType, weld::Entry& rEdit, const ScDocument* pDoc )
+void SetDataBarEntryTypes( const ScColorScaleEntry& rEntry, weld::ComboBox& rLbType, weld::Entry& rEdit, const ScDocument& rDoc )
 {
     selectType(rLbType, rEntry.GetType());
     switch(rEntry.GetType())
@@ -1073,9 +1078,8 @@ void SetDataBarEntryTypes( const ScColorScaleEntry& rEntry, weld::ComboBox& rLbT
         case COLORSCALE_PERCENTILE:
             {
                 double nVal = rEntry.GetValue();
-                SvNumberFormatter* pNumberFormatter = pDoc->GetFormatTable();
-                OUString aText;
-                pNumberFormatter->GetInputLineString(nVal, 0, aText);
+                SvNumberFormatter* pNumberFormatter = rDoc.GetFormatTable();
+                OUString aText = pNumberFormatter->GetInputLineString(nVal, 0);
                 rEdit.set_text(aText);
             }
             break;
@@ -1087,8 +1091,8 @@ void SetDataBarEntryTypes( const ScColorScaleEntry& rEntry, weld::ComboBox& rLbT
 
 }
 
-ScDataBarFrmtEntry::ScDataBarFrmtEntry(ScCondFormatList* pParent, ScDocument* pDoc, const ScAddress& rPos, const ScDataBarFormat* pFormat)
-    : ScCondFrmtEntry(pParent, pDoc, rPos)
+ScDataBarFrmtEntry::ScDataBarFrmtEntry(ScCondFormatList* pParent, ScDocument& rDoc, const ScAddress& rPos, const ScDataBarFormat* pFormat)
+    : ScCondFrmtEntry(pParent, rDoc, rPos)
     , mxLbColorFormat(mxBuilder->weld_combo_box(u"colorformat"_ustr))
     , mxLbDataBarMinType(mxBuilder->weld_combo_box(u"colscalemin"_ustr))
     , mxLbDataBarMaxType(mxBuilder->weld_combo_box(u"colscalemax"_ustr))
@@ -1114,8 +1118,8 @@ ScDataBarFrmtEntry::ScDataBarFrmtEntry(ScCondFormatList* pParent, ScDocument* pD
     if(pFormat)
     {
         mpDataBarData.reset(new ScDataBarFormatData(*pFormat->GetDataBarData()));
-        SetDataBarEntryTypes(*mpDataBarData->mpLowerLimit, *mxLbDataBarMinType, *mxEdDataBarMin, pDoc);
-        SetDataBarEntryTypes(*mpDataBarData->mpUpperLimit, *mxLbDataBarMaxType, *mxEdDataBarMax, pDoc);
+        SetDataBarEntryTypes(*mpDataBarData->mpLowerLimit, *mxLbDataBarMinType, *mxEdDataBarMin, rDoc);
+        SetDataBarEntryTypes(*mpDataBarData->mpUpperLimit, *mxLbDataBarMaxType, *mxEdDataBarMax, rDoc);
         DataBarTypeSelectHdl(*mxLbDataBarMinType);
     }
     else
@@ -1159,10 +1163,10 @@ void ScDataBarFrmtEntry::Init()
 ScFormatEntry* ScDataBarFrmtEntry::createDatabarEntry() const
 {
     SetColorScaleEntry(mpDataBarData->mpLowerLimit.get(), *mxLbDataBarMinType,
-                       *mxEdDataBarMin, mpDoc, maPos);
+                       *mxEdDataBarMin, mrDoc, maPos);
     SetColorScaleEntry(mpDataBarData->mpUpperLimit.get(), *mxLbDataBarMaxType,
-                       *mxEdDataBarMax, mpDoc, maPos);
-    ScDataBarFormat* pDataBar = new ScDataBarFormat(mpDoc);
+                       *mxEdDataBarMax, mrDoc, maPos);
+    ScDataBarFormat* pDataBar = new ScDataBarFormat(&mrDoc);
     pDataBar->SetDataBarData(new ScDataBarFormatData(*mpDataBarData));
     return pDataBar;
 }
@@ -1214,21 +1218,21 @@ IMPL_LINK_NOARG( ScDataBarFrmtEntry, DataBarTypeSelectHdl, weld::ComboBox&, void
 IMPL_LINK_NOARG( ScDataBarFrmtEntry, OptionBtnHdl, weld::Button&, void )
 {
     SetColorScaleEntry(mpDataBarData->mpLowerLimit.get(), *mxLbDataBarMinType,
-                       *mxEdDataBarMin, mpDoc, maPos);
+                       *mxEdDataBarMin, mrDoc, maPos);
     SetColorScaleEntry(mpDataBarData->mpUpperLimit.get(), *mxLbDataBarMaxType,
-                       *mxEdDataBarMax, mpDoc, maPos);
-    ScDataBarSettingsDlg aDlg(mpParent->GetFrameWeld(), *mpDataBarData, mpDoc, maPos);
+                       *mxEdDataBarMax, mrDoc, maPos);
+    ScDataBarSettingsDlg aDlg(mpParent->GetFrameWeld(), *mpDataBarData, mrDoc, maPos);
     if (aDlg.run() == RET_OK)
     {
         mpDataBarData.reset(aDlg.GetData());
-        SetDataBarEntryTypes(*mpDataBarData->mpLowerLimit, *mxLbDataBarMinType, *mxEdDataBarMin, mpDoc);
-        SetDataBarEntryTypes(*mpDataBarData->mpUpperLimit, *mxLbDataBarMaxType, *mxEdDataBarMax, mpDoc);
+        SetDataBarEntryTypes(*mpDataBarData->mpLowerLimit, *mxLbDataBarMinType, *mxEdDataBarMin, mrDoc);
+        SetDataBarEntryTypes(*mpDataBarData->mpUpperLimit, *mxLbDataBarMaxType, *mxEdDataBarMax, mrDoc);
         DataBarTypeSelectHdl(*mxLbDataBarMinType);
     }
 }
 
-ScDateFrmtEntry::ScDateFrmtEntry(ScCondFormatList* pParent, ScDocument* pDoc, const ScCondDateFormatEntry* pFormat)
-    : ScCondFrmtEntry(pParent, pDoc, ScAddress())
+ScDateFrmtEntry::ScDateFrmtEntry(ScCondFormatList* pParent, ScDocument& rDoc, const ScCondDateFormatEntry* pFormat)
+    : ScCondFrmtEntry(pParent, rDoc, ScAddress())
     , mxLbDateEntry(mxBuilder->weld_combo_box(u"datetype"_ustr))
     , mxFtStyle(mxBuilder->weld_label(u"styleft"_ustr))
     , mxLbStyle(mxBuilder->weld_combo_box(u"style"_ustr))
@@ -1243,7 +1247,7 @@ ScDateFrmtEntry::ScDateFrmtEntry(ScCondFormatList* pParent, ScDocument* pDoc, co
 
     Init();
 
-    StartListening(*pDoc->GetStyleSheetPool(), DuplicateHandling::Prevent);
+    StartListening(*rDoc.GetStyleSheetPool(), DuplicateHandling::Prevent);
 
     if(pFormat)
     {
@@ -1265,7 +1269,7 @@ void ScDateFrmtEntry::Init()
     mxLbDateEntry->set_active(0);
     mxLbType->set_active(3);
 
-    FillStyleListBox( mpDoc, *mxLbStyle );
+    FillStyleListBox(&mrDoc, *mxLbStyle);
     mxLbStyle->connect_changed( LINK( this, ScDateFrmtEntry, StyleSelectHdl ) );
     mxLbStyle->set_active(1);
 }
@@ -1295,13 +1299,13 @@ void ScDateFrmtEntry::Notify( SfxBroadcaster&, const SfxHint& rHint )
     if(rHint.GetId() == SfxHintId::StyleSheetModified || rHint.GetId() == SfxHintId::StyleSheetModifiedExtended)
     {
         if(!mbIsInStyleCreate)
-            UpdateStyleList(*mxLbStyle, mpDoc);
+            UpdateStyleList(*mxLbStyle, &mrDoc);
     }
 }
 
 ScFormatEntry* ScDateFrmtEntry::GetEntry() const
 {
-    ScCondDateFormatEntry* pNewEntry = new ScCondDateFormatEntry(mpDoc);
+    ScCondDateFormatEntry* pNewEntry = new ScCondDateFormatEntry(&mrDoc);
     condformat::ScCondFormatDateType eType = static_cast<condformat::ScCondFormatDateType>(mxLbDateEntry->get_active());
     pNewEntry->SetDateType(eType);
     pNewEntry->SetStyleName(mxLbStyle->get_active_text());
@@ -1317,7 +1321,7 @@ OUString ScDateFrmtEntry::GetExpressionString()
 IMPL_LINK_NOARG( ScDateFrmtEntry, StyleSelectHdl, weld::ComboBox&, void )
 {
     mbIsInStyleCreate = true;
-    StyleSelect(mpParent->GetFrameWeld(), *mxLbStyle, mpDoc, maWdPreview);
+    StyleSelect(mpParent->GetFrameWeld(), *mxLbStyle, &mrDoc, maWdPreview);
     mbIsInStyleCreate = false;
 }
 
@@ -1334,7 +1338,7 @@ private:
     weld::Container* mpContainer;
 
 public:
-    ScIconSetFrmtDataEntry(weld::Container* pParent, ScIconSetType eType, const ScDocument* pDoc,
+    ScIconSetFrmtDataEntry(weld::Container* pParent, ScIconSetType eType, const ScDocument& rDoc,
             sal_Int32 i, const ScColorScaleEntry* pEntry = nullptr);
     ~ScIconSetFrmtDataEntry();
     void Show() { mxGrid->show(); }
@@ -1350,7 +1354,7 @@ public:
     void SetFirstEntry();
 };
 
-ScIconSetFrmtDataEntry::ScIconSetFrmtDataEntry(weld::Container* pParent, ScIconSetType eType, const ScDocument* pDoc, sal_Int32 i, const ScColorScaleEntry* pEntry)
+ScIconSetFrmtDataEntry::ScIconSetFrmtDataEntry(weld::Container* pParent, ScIconSetType eType, const ScDocument& rDoc, sal_Int32 i, const ScColorScaleEntry* pEntry)
     : mxBuilder(Application::CreateBuilder(pParent, u"modules/scalc/ui/conditionaliconset.ui"_ustr))
     , mxGrid(mxBuilder->weld_container(u"ConditionalIconSet"_ustr))
     , mxImgIcon(mxBuilder->weld_image(u"icon"_ustr))
@@ -1362,19 +1366,22 @@ ScIconSetFrmtDataEntry::ScIconSetFrmtDataEntry(weld::Container* pParent, ScIconS
     mxImgIcon->set_from_icon_name(ScIconSetFormat::getIconName(eType, i));
     if(pEntry)
     {
+        // tdf#162948: Use ">" instead of ">=". Add some spaces to keep the alignment
+        if (!pEntry->GetGreaterThanOrEqual())
+            mxFtEntry->set_label(" >   ");
         switch(pEntry->GetType())
         {
             case COLORSCALE_VALUE:
                 mxLbEntryType->set_active(0);
-                mxEdEntry->set_text(convertNumberToString(pEntry->GetValue(), pDoc));
+                mxEdEntry->set_text(convertNumberToString(pEntry->GetValue(), rDoc));
                 break;
             case COLORSCALE_PERCENTILE:
                 mxLbEntryType->set_active(2);
-                mxEdEntry->set_text(convertNumberToString(pEntry->GetValue(), pDoc));
+                mxEdEntry->set_text(convertNumberToString(pEntry->GetValue(), rDoc));
                 break;
             case COLORSCALE_PERCENT:
                 mxLbEntryType->set_active(1);
-                mxEdEntry->set_text(convertNumberToString(pEntry->GetValue(), pDoc));
+                mxEdEntry->set_text(convertNumberToString(pEntry->GetValue(), rDoc));
                 break;
             case COLORSCALE_FORMULA:
                 mxLbEntryType->set_active(3);
@@ -1438,8 +1445,8 @@ void ScIconSetFrmtDataEntry::SetFirstEntry()
     mxLbEntryType->set_active(1);
 }
 
-ScIconSetFrmtEntry::ScIconSetFrmtEntry(ScCondFormatList* pParent, ScDocument* pDoc, const ScAddress& rPos, const ScIconSetFormat* pFormat)
-    : ScCondFrmtEntry(pParent, pDoc, rPos)
+ScIconSetFrmtEntry::ScIconSetFrmtEntry(ScCondFormatList* pParent, ScDocument& rDoc, const ScAddress& rPos, const ScIconSetFormat* pFormat)
+    : ScCondFrmtEntry(pParent, rDoc, rPos)
     , mxLbColorFormat(mxBuilder->weld_combo_box(u"colorformat"_ustr))
     , mxLbIconSetType(mxBuilder->weld_combo_box(u"iconsettype"_ustr))
     , mxIconParent(mxBuilder->weld_container(u"iconparent"_ustr))
@@ -1461,7 +1468,7 @@ ScIconSetFrmtEntry::ScIconSetFrmtEntry(ScCondFormatList* pParent, ScDocument* pD
                 i < n; ++i)
         {
             maEntries.emplace_back(new ScIconSetFrmtDataEntry(
-                mxIconParent.get(), eType, pDoc, i, pIconSetFormatData->m_Entries[i].get()));
+                mxIconParent.get(), eType, rDoc, i, pIconSetFormatData->m_Entries[i].get()));
             maEntries[i]->set_grid_top_attach(i);
         }
         maEntries[0]->SetFirstEntry();
@@ -1494,7 +1501,7 @@ IMPL_LINK_NOARG( ScIconSetFrmtEntry, IconSetTypeHdl, weld::ComboBox&, void )
 
     for(size_t i = 0; i < nElements; ++i)
     {
-        maEntries.emplace_back(new ScIconSetFrmtDataEntry(mxIconParent.get(), static_cast<ScIconSetType>(nPos), mpDoc, i));
+        maEntries.emplace_back(new ScIconSetFrmtDataEntry(mxIconParent.get(), static_cast<ScIconSetType>(nPos), mrDoc, i));
         maEntries[i]->set_grid_top_attach(i);
         maEntries[i]->Show();
     }
@@ -1532,13 +1539,13 @@ void ScIconSetFrmtEntry::SetInactive()
 
 ScFormatEntry* ScIconSetFrmtEntry::GetEntry() const
 {
-    ScIconSetFormat* pFormat = new ScIconSetFormat(mpDoc);
+    ScIconSetFormat* pFormat = new ScIconSetFormat(&mrDoc);
 
     ScIconSetFormatData* pData = new ScIconSetFormatData;
     pData->eIconSetType = static_cast<ScIconSetType>(mxLbIconSetType->get_active());
     for(const auto& rxEntry : maEntries)
     {
-        pData->m_Entries.emplace_back(rxEntry->CreateEntry(*mpDoc, maPos));
+        pData->m_Entries.emplace_back(rxEntry->CreateEntry(mrDoc, maPos));
     }
     pFormat->SetIconSetData(pData);
 
