@@ -192,7 +192,7 @@ void SwMacrosTest::testBookmarkDeleteAndJoin()
     aPaM.SetMark();
     aPaM.Move(fnMoveForward, GoInDoc);
     IDocumentMarkAccess & rIDMA = *pDoc->getIDocumentMarkAccess();
-    sw::mark::IMark *pMark =
+    sw::mark::MarkBase *pMark =
         rIDMA.makeMark(aPaM, u"test"_ustr, IDocumentMarkAccess::MarkType::BOOKMARK,
             ::sw::mark::InsertMode::New);
     CPPUNIT_ASSERT(pMark);
@@ -205,7 +205,7 @@ void SwMacrosTest::testBookmarkDeleteAndJoin()
     // delete
     rIDCO.DeleteAndJoin(aPaM);
 
-    for (IDocumentMarkAccess::const_iterator_t i = rIDMA.getAllMarksBegin(); i != rIDMA.getAllMarksEnd(); ++i)
+    for (auto i = rIDMA.getAllMarksBegin(); i != rIDMA.getAllMarksEnd(); ++i)
     {
         // problem was that the nContent was pointing at deleted node
         CPPUNIT_ASSERT_EQUAL((*i)->GetMarkStart().GetContentNode(),
@@ -227,7 +227,7 @@ void SwMacrosTest::testBookmarkDeleteTdf90816()
     aPaM.SetMark();
     aPaM.Move(fnMoveBackward, GoInContent);
     IDocumentMarkAccess & rIDMA = *pDoc->getIDocumentMarkAccess();
-    sw::mark::IMark *pMark =
+    sw::mark::MarkBase *pMark =
         rIDMA.makeMark(aPaM, u"test"_ustr, IDocumentMarkAccess::MarkType::BOOKMARK,
             ::sw::mark::InsertMode::New);
     CPPUNIT_ASSERT(pMark);
@@ -424,7 +424,7 @@ void SwMacrosTest::testFdo68983()
 
 void SwMacrosTest::testFdo87530()
 {
-    mxComponent = loadFromDesktop(u"private:factory/swriter"_ustr, u"com.sun.star.text.TextDocument"_ustr);
+    loadFromURL(u"private:factory/swriter"_ustr);
 
     {
         // insert initial password protected library
@@ -481,8 +481,7 @@ void SwMacrosTest::testFdo87530()
 void SwMacrosTest::testFindReplace()
 {
     // we need a full document with view and layout etc. because ::GetNode()
-    mxComponent =
-        loadFromDesktop(u"private:factory/swriter"_ustr, u"com.sun.star.text.TextDocument"_ustr);
+    loadFromURL(u"private:factory/swriter"_ustr);
 
     SwXTextDocument *const pTextDoc = dynamic_cast<SwXTextDocument *>(mxComponent.get());
     CPPUNIT_ASSERT(pTextDoc);
