@@ -1728,6 +1728,76 @@ CPPUNIT_TEST_FIXTURE(SwLayoutWriter5, testTdf165094)
     assertXPath(pXmlDoc, "//page[3]/body/tab", 1);
 }
 
+CPPUNIT_TEST_FIXTURE(SwLayoutWriter5, testTdf166691)
+{
+    // Given a document with a table which disallows breaking across pages, and that has a cell
+    // with an inner section with hide condition (evaluated to true), such as to have the cell
+    // height enough to fit on page 1, when the section is hidden, but too tall when it's shown:
+    createSwDoc("table-with-hidden-section.fodt");
+    auto pXmlDoc = parseLayoutDump();
+
+    // Check that there is only a single page
+    assertXPath(pXmlDoc, "//page", 1);
+}
+
+CPPUNIT_TEST_FIXTURE(SwLayoutWriter5, testTdf166871)
+{
+    // Given a document with 6-column-layout pages, having hundreds of small paragraphs per page
+    // (normal and headings); its metadata has the number of pages, paragraphs, etc.:
+    createSwDoc("many-paragraphs-per-page-in-6-columns.odt");
+    auto pXmlDoc = parseLayoutDump();
+
+    // Check the layout - i.e., the count of paragraphs per column per page.
+    // The metadata in the document must not prevent the correct layout.
+
+    assertXPath(pXmlDoc, "//page", 12);
+
+    // The first 11 pages have the same paragraph count in each column
+    for (int page = 1; page <= 11; ++page)
+    {
+        OString Xpath1 = "//page[" + OString::number(page) + "]/body/column";
+        assertXPath(pXmlDoc, Xpath1, 6);
+        for (int column = 1; column <= 6; ++column)
+        {
+            OString Xpath2 = Xpath1 + "[" + OString::number(column) + "]/body/txt";
+            assertXPath(pXmlDoc, Xpath2, 47);
+        }
+    }
+
+    // Check the last page
+    assertXPath(pXmlDoc, "//page[12]/body/column", 6);
+    assertXPath(pXmlDoc, "//page[12]/body/column[1]/body/txt", 14);
+    assertXPath(pXmlDoc, "//page[12]/body/column[2]/body/txt", 0);
+    assertXPath(pXmlDoc, "//page[12]/body/column[3]/body/txt", 0);
+    assertXPath(pXmlDoc, "//page[12]/body/column[4]/body/txt", 0);
+    assertXPath(pXmlDoc, "//page[12]/body/column[5]/body/txt", 0);
+    assertXPath(pXmlDoc, "//page[12]/body/column[6]/body/txt", 0);
+}
+
+CPPUNIT_TEST_FIXTURE(SwLayoutWriter5, testTdf166978)
+{
+    // Given a document with a table, which cell has a section:
+    createSwDoc("hideSection.fodt");
+    CPPUNIT_ASSERT_EQUAL(1, getPages());
+
+    // Hide the section
+    auto xTextSectionsSupplier = mxComponent.queryThrow<css::text::XTextSectionsSupplier>();
+    auto xSections = xTextSectionsSupplier->getTextSections();
+    CPPUNIT_ASSERT(xSections);
+    auto xSection = xSections->getByName(u"Section1"_ustr).queryThrow<css::beans::XPropertySet>();
+    xSection->setPropertyValue(u"IsVisible"_ustr, css::uno::Any(false));
+    Scheduler::ProcessEventsToIdle();
+
+    CPPUNIT_ASSERT_EQUAL(1, getPages()); // must not split the second row of the table to page 2
+    // Check the layout dump; the whole table must be still on the first page
+    auto pXmlDoc = parseLayoutDump();
+    assertXPath(pXmlDoc, "//page", 1);
+    assertXPath(pXmlDoc, "//page[1]/body/tab", 1);
+    assertXPath(pXmlDoc, "//page[1]/body/tab/row", 2);
+    assertXPathContent(pXmlDoc, "//page[1]/body/tab/row[2]/cell[1]",
+                       u"A2: this row suddenly jumps to the next page");
+}
+
 CPPUNIT_PLUGIN_IMPLEMENT();
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
