@@ -1661,6 +1661,14 @@ CPPUNIT_TEST_FIXTURE(Test, testTdf163974)
     CPPUNIT_ASSERT_EQUAL(size_t(1), footnotes.Count());
 }
 
+CPPUNIT_TEST_FIXTURE(Test, testTdf167329)
+{
+    // This used to fail an assertion during loafing, because some inserted frames didn't
+    // update their inf flags, and still reported to be not in body.
+    createSwDoc("chained-boxes-in-min-height-cells.fodt");
+    // This must succeed
+}
+
 } // end of anonymous namespace
 CPPUNIT_PLUGIN_IMPLEMENT();
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
