@@ -106,8 +106,7 @@ std::unique_ptr<SwTextBlocks> SwUiWriterTest::readDOCXAutotext(std::u16string_vi
 void SwUiWriterTest::testRedlineFrame(char const*const file)
 {
     createSwDoc(file);
-    SwDoc* pDoc = getSwDoc();
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
 
     // there is exactly one frame
     CPPUNIT_ASSERT_EQUAL(1, getShapes());
@@ -213,9 +212,8 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testThreadedException)
 CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testTdf149595)
 {
     createSwDoc("demo91.fodt");
-    SwDoc* pDoc = getSwDoc();
 
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
 
     // all 4 shapes are on the 2nd paragraph
     CPPUNIT_ASSERT(pWrtShell->GetLayout()->GetLower()->GetLower()->GetLower()->GetDrawObjs() == nullptr);
@@ -322,7 +320,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testPasteTableAtFlyAnchor)
 {
     createSwDoc();
     SwDoc* pDoc = getSwDoc();
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
 
     SwFormatAnchor anchor(RndStdIds::FLY_AT_CHAR);
     anchor.SetAnchor(pWrtShell->GetCursor()->GetPoint());
@@ -378,23 +376,17 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testPasteTableAtFlyAnchor)
 
 CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testCopyPastePageBreak)
 {
-    {
-        createSwDoc("pagebreak-source.fodt");
-        SwDoc* pDoc = getSwDoc();
+    createSwDoc("pagebreak-source.fodt");
 
-        SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
-        CPPUNIT_ASSERT_EQUAL(tools::Long(5669), pWrtShell->GetLayout()->GetLower()->getFramePrintArea().Top());
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
+    CPPUNIT_ASSERT_EQUAL(tools::Long(5669), pWrtShell->GetLayout()->GetLower()->getFramePrintArea().Top());
 
-        pWrtShell->SelAll();
-        dispatchCommand(mxComponent, u".uno:Copy"_ustr, {});
-
-        mxComponent->dispose();
-        mxComponent.clear();
-    }
+    pWrtShell->SelAll();
+    dispatchCommand(mxComponent, u".uno:Copy"_ustr, {});
 
     createSwDoc("pagebreak-target.fodt");
     SwDoc* pDoc = getSwDoc();
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    pWrtShell = getSwDocShell()->GetWrtShell();
 
     CPPUNIT_ASSERT_EQUAL(1, getParagraphs());
     CPPUNIT_ASSERT_EQUAL(u"WithMargin"_ustr, getProperty<OUString>(getParagraph(1), u"PageDescName"_ustr));
@@ -500,8 +492,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testFormulaNumberWithGroupSeparator)
 {
     createSwDoc("tdf125154.odt");
     dispatchCommand(mxComponent, u".uno:UpdateAll"_ustr, {});
-    SwDoc* pDoc = getSwDoc();
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
     pWrtShell->SttEndDoc(true);
     SwField const* pField;
 
@@ -565,7 +556,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testTdf67238)
     //create a new writer document
     createSwDoc();
     SwDoc* pDoc = getSwDoc();
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
     sw::UndoManager& rUndoManager = pDoc->GetUndoManager();
     //insert a 3X3 table in the newly created document
     SwInsertTableOptions TableOpt(SwInsertTableFlags::DefaultBorder, 0);
@@ -657,8 +648,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testTdf67238)
 CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testTdf155685)
 {
     createSwDoc("table-at-end-of-cell.fodt");
-    SwDoc* pDoc = getSwDoc();
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
     pWrtShell->GoNextCell();
     pWrtShell->GoNextCell();
     pWrtShell->GoNextCell();
@@ -676,7 +666,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testTdf147220)
 {
     createSwDoc();
     SwDoc* pDoc = getSwDoc();
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
 
     pWrtShell->Insert(u"él"_ustr);
 
@@ -714,7 +704,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testTdf135978)
 {
     createSwDoc();
     SwDoc* pDoc = getSwDoc();
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
 
     pWrtShell->Insert(u"foobar"_ustr);
     pWrtShell->SplitNode();
@@ -766,7 +756,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testFdo75110)
 {
     createSwDoc("fdo75110.odt");
     SwDoc* pDoc = getSwDoc();
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
 
     pWrtShell->SelAll();
     // The problem was that SwEditShell::DeleteSel() what this Delete() invokes took the wrong selection...
@@ -779,8 +769,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testFdo75110)
 CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testFdo75898)
 {
     createSwDoc("fdo75898.odt");
-    SwDoc* pDoc = getSwDoc();
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
     pWrtShell->SelAll();
     pWrtShell->InsertRow(1, true);
     pWrtShell->InsertRow(1, true);
@@ -820,8 +809,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testReplaceBackward)
 CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testFdo69893)
 {
     createSwDoc("fdo69893.odt");
-    SwDoc* pDoc = getSwDoc();
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
 
     pWrtShell->SelAll(); // A1 is empty -> selects the whole table.
     pWrtShell->SelAll(); // Selects the whole document.
@@ -865,7 +853,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testImportRTF)
     // Insert "foobar" and position the cursor between "foo" and "bar".
     createSwDoc();
     SwDoc* pDoc = getSwDoc();
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
     pWrtShell->Insert(u"foobar"_ustr);
     pWrtShell->Left(SwCursorSkipMode::Chars, /*bSelect=*/false, 3, /*bBasicCall=*/false);
 
@@ -886,8 +874,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testExportRTF)
 {
     // Insert "aaabbbccc" and select "bbb".
     createSwDoc();
-    SwDoc* pDoc = getSwDoc();
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
     pWrtShell->Insert(u"aaabbbccc"_ustr);
     pWrtShell->Left(SwCursorSkipMode::Chars, /*bSelect=*/false, 3, /*bBasicCall=*/false);
     pWrtShell->Left(SwCursorSkipMode::Chars, /*bSelect=*/true, 3, /*bBasicCall=*/false);
@@ -1005,8 +992,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testDOCXAutoTextGallery)
 CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testWatermarkDOCX)
 {
     createSwDoc("watermark.docx");
-    SwDoc* const pDoc = getSwDoc();
-    SwDocShell* pDocShell = pDoc->GetDocShell();
+    SwDocShell* pDocShell = getSwDocShell();
     SfxPoolItemHolder aResult;
     SfxItemState eState = pDocShell->GetViewShell()->GetViewFrame().GetDispatcher()->QueryState(SID_WATERMARK, aResult);
     const SfxWatermarkItem* pWatermark(static_cast<const SfxWatermarkItem*>(aResult.getItem()));
@@ -1038,9 +1024,9 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testWatermarkPosition)
         SwDoc* pDoc = getSwDoc();
         SwEditShell* pEditShell = pDoc->GetEditShell();
         CPPUNIT_ASSERT(pEditShell);
-        SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
-        uno::Reference<frame::XModel> xModel = pDoc->GetDocShell()->GetBaseModel();
-        uno::Reference<style::XStyleFamiliesSupplier> xStyleFamiliesSupplier(xModel, uno::UNO_QUERY);
+        SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
+        uno::Reference<style::XStyleFamiliesSupplier> xStyleFamiliesSupplier(mxComponent,
+                                                                         uno::UNO_QUERY);
         uno::Reference<container::XNameAccess> xStyleFamilies = xStyleFamiliesSupplier->getStyleFamilies();
 
         // 1. Add additional page breaks
@@ -1104,7 +1090,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testFdo74981)
     // create a document with an input field
     createSwDoc();
     SwDoc* pDoc = getSwDoc();
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
     SwInputField aField(static_cast<SwInputFieldType*>(pWrtShell->GetFieldType(0, SwFieldIds::Input)), u"foo"_ustr, u"bar"_ustr, 0, 0);
     pWrtShell->InsertField2(aField);
 
@@ -1134,7 +1120,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testTdf98512)
 {
     createSwDoc();
     SwDoc* pDoc = getSwDoc();
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
     SwInputFieldType *const pType(static_cast<SwInputFieldType*>(
                 pWrtShell->GetFieldType(0, SwFieldIds::Input)));
     SwInputField aField1(pType, u"foo"_ustr, u"bar"_ustr, INP_TXT, 0);
@@ -1173,7 +1159,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testShapeTextboxSelect)
 {
     createSwDoc("shape-textbox.odt");
     SwDoc* pDoc = getSwDoc();
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
     SdrPage* pPage = pDoc->getIDocumentDrawModelAccess().GetDrawModel()->GetPage(0);
     SdrObject* pObject = pPage->GetObj(1);
     SwContact* pTextBox = static_cast<SwContact*>(pObject->GetUserCall());
@@ -1192,7 +1178,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testShapeTextboxDelete)
 {
     createSwDoc("shape-textbox.odt");
     SwDoc* pDoc = getSwDoc();
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
     SdrPage* pPage = pDoc->getIDocumentDrawModelAccess().GetDrawModel()->GetPage(0);
     SdrObject* pObject = pPage->GetObj(0);
     pWrtShell->SelectObj(Point(), 0, pObject);
@@ -1210,7 +1196,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testAnchorChangeSelection)
 {
     createSwDoc("test_anchor_as_character.odt");
     SwDoc* pDoc = getSwDoc();
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
     SdrPage* pPage = pDoc->getIDocumentDrawModelAccess().GetDrawModel()->GetPage(0);
     SdrObject* pObject = pPage->GetObj(0);
     CPPUNIT_ASSERT(pObject);
@@ -1230,7 +1216,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testCp1000071)
 {
     createSwDoc("cp1000071.odt");
     SwDoc* pDoc = getSwDoc();
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
 
     const SwRedlineTable& rTable = pDoc->getIDocumentRedlineAccess().GetRedlineTable();
     CPPUNIT_ASSERT_EQUAL( SwRedlineTable::size_type( 2 ), rTable.size());
@@ -1246,7 +1232,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testCp1000071)
     // Change the document layout to be 2 columns, and then undo.
     pWrtShell->SelAll();
     SwSectionData section(SectionType::Content, pWrtShell->GetUniqueSectionName());
-    SfxItemSet set( pDoc->GetDocShell()->GetPool(), svl::Items<RES_COL, RES_COL> );
+    SfxItemSet set( getSwDocShell()->GetPool(), svl::Items<RES_COL, RES_COL> );
     SwFormatCol col;
     col.Init( 2, 0, 10000 );
     set.Put( col );
@@ -1305,7 +1291,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testFdo82191)
     CPPUNIT_ASSERT_EQUAL(sal_Int32(1), SwTextBoxHelper::getCount(pPage));
 
     SwDoc aClipboard;
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
     SdrObject* pObject = pPage->GetObj(0);
     // Select it, then copy and paste.
     pWrtShell->SelectObj(Point(), 0, pObject);
@@ -1321,8 +1307,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testCommentedWord)
     // This word is commented. <- string in document
     // 123456789 <- character positions
     createSwDoc("commented-word.odt");
-    SwDoc* pDoc = getSwDoc();
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
     // Move the cursor into the second word.
     pWrtShell->Right(SwCursorSkipMode::Chars, /*bSelect=*/false, 5, /*bBasicCall=*/false);
     // Select the word.
@@ -1361,7 +1346,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testChineseConversionBlank)
     // Given
     createSwDoc();
     SwDoc* pDoc = getSwDoc();
-    SwView* pView = pDoc->GetDocShell()->GetView();
+    SwView* pView = getSwDocShell()->GetView();
     const uno::Reference< uno::XComponentContext > xContext( comphelper::getProcessComponentContext() );
     SwNodeIndex aIdx(pDoc->GetNodes().GetEndOfContent(), -1);
     SwPaM aPaM(aIdx);
@@ -1385,7 +1370,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testChineseConversionNonChineseText)
     // Given
     createSwDoc();
     SwDoc* pDoc = getSwDoc();
-    SwView* pView = pDoc->GetDocShell()->GetView();
+    SwView* pView = getSwDocShell()->GetView();
     const uno::Reference< uno::XComponentContext > xContext( comphelper::getProcessComponentContext() );
     SwNodeIndex aIdx(pDoc->GetNodes().GetEndOfContent(), -1);
     SwPaM aPaM(aIdx);
@@ -1410,7 +1395,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testChineseConversionTraditionalToSimplifie
     // Given
     createSwDoc();
     SwDoc* pDoc = getSwDoc();
-    SwView* pView = pDoc->GetDocShell()->GetView();
+    SwView* pView = getSwDocShell()->GetView();
     const uno::Reference< uno::XComponentContext > xContext( comphelper::getProcessComponentContext() );
     SwNodeIndex aIdx(pDoc->GetNodes().GetEndOfContent(), -1);
     SwPaM aPaM(aIdx);
@@ -1435,7 +1420,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testChineseConversionSimplifiedToTraditiona
     // Given
     createSwDoc();
     SwDoc* pDoc = getSwDoc();
-    SwView* pView = pDoc->GetDocShell()->GetView();
+    SwView* pView = getSwDocShell()->GetView();
     const uno::Reference< uno::XComponentContext > xContext( comphelper::getProcessComponentContext() );
     SwNodeIndex aIdx(pDoc->GetNodes().GetEndOfContent(), -1);
     SwPaM aPaM(aIdx);
@@ -1477,17 +1462,17 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testFdo85554)
 CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testMergeDoc)
 {
     createSwDoc("merge-change1.odt");
-    SwDoc* pDoc1 = getSwDoc();
+    SwDoc* pDoc = getSwDoc();
 
-    auto xDoc2Component(loadFromDesktop(
+    mxComponent2 = loadFromDesktop(
             createFileURL(u"merge-change2.odt"),
-            u"com.sun.star.text.TextDocument"_ustr));
+            u"com.sun.star.text.TextDocument"_ustr);
     auto pxDoc2Document(
-            dynamic_cast<SwXTextDocument *>(xDoc2Component.get()));
+            dynamic_cast<SwXTextDocument *>(mxComponent2.get()));
     CPPUNIT_ASSERT(pxDoc2Document);
     SwDoc* const pDoc2(pxDoc2Document->GetDocShell()->GetDoc());
 
-    SwEditShell* const pEditShell(pDoc1->GetEditShell());
+    SwEditShell* const pEditShell(pDoc->GetEditShell());
     CPPUNIT_ASSERT(pEditShell);
     pEditShell->MergeDoc(*pDoc2);
 
@@ -1503,8 +1488,6 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testMergeDoc)
     getParagraph(5, u"Para Six: One Three Four Five"_ustr);
     getParagraph(6, u""_ustr);
     getParagraph(7, u""_ustr);
-
-    xDoc2Component->dispose();
 }
 
 CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testCreatePortions)
@@ -1538,7 +1521,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testBookmarkUndo)
     rUndoManager.Redo();
     CPPUNIT_ASSERT_EQUAL(sal_Int32(1), pMarkAccess->getAllMarksCount());
 
-    IDocumentMarkAccess::const_iterator_t ppBkmk = pMarkAccess->findMark(u"Mark"_ustr);
+    auto ppBkmk = pMarkAccess->findMark(u"Mark"_ustr);
     CPPUNIT_ASSERT(ppBkmk != pMarkAccess->getAllMarksEnd());
 
     pMarkAccess->renameMark(*ppBkmk, u"Mark_"_ustr);
@@ -1563,7 +1546,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testTdf148389_Left)
 {
     createSwDoc();
     SwDoc* pDoc = getSwDoc();
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
     CPPUNIT_ASSERT(pWrtShell);
     pWrtShell->Insert(u"foo bar baz"_ustr);
     pWrtShell->Left(SwCursorSkipMode::Chars, /*bSelect=*/false, 4, /*bBasicCall=*/false);
@@ -1626,7 +1609,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testTdf148389_Right)
 {
     createSwDoc();
     SwDoc* pDoc = getSwDoc();
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
     CPPUNIT_ASSERT(pWrtShell);
     pWrtShell->Insert(u"foo bar baz"_ustr);
     pWrtShell->Left(SwCursorSkipMode::Chars, /*bSelect=*/false, 4, /*bBasicCall=*/false);
@@ -1716,8 +1699,7 @@ static void lcl_setWeight(SwWrtShell* pWrtShell, FontWeight aWeight)
 CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testFdo85876)
 {
     createSwDoc();
-    SwDoc* const pDoc = getSwDoc();
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
     lcl_setWeight(pWrtShell, WEIGHT_BOLD);
     pWrtShell->Insert(u"test"_ustr);
     lcl_setWeight(pWrtShell, WEIGHT_NORMAL);
@@ -1745,8 +1727,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testFdo85876)
 CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testCaretPositionMovingUp)
 {
     createSwDoc();
-    SwDoc* const pDoc = getSwDoc();
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
     pWrtShell->Insert(u"after"_ustr);
     pWrtShell->InsertLineBreak();
     pWrtShell->Up(false);
@@ -1758,8 +1739,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testCaretPositionMovingUp)
 CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testTdf93441)
 {
     createSwDoc();
-    SwDoc* const pDoc = getSwDoc();
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
     pWrtShell->Insert(u"Hello"_ustr);
     pWrtShell->InsertLineBreak();
     pWrtShell->Insert(u"Hello World"_ustr);
@@ -1775,8 +1755,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testTdf93441)
 CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testTdf81226)
 {
     createSwDoc();
-    SwDoc* const pDoc = getSwDoc();
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
     pWrtShell->Insert(u"before"_ustr);
     pWrtShell->Left(SwCursorSkipMode::Chars, /*bSelect=*/false, 4, /*bBasicCall=*/false);
     pWrtShell->Down(false);
@@ -1791,8 +1770,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testTdf81226)
 CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testTdf137532)
 {
     createSwDoc();
-    SwDoc* const pDoc = getSwDoc();
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
     pWrtShell->Insert(u"test"_ustr);
 
     //Select the word and change it to bold
@@ -1859,10 +1837,10 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testFdo87448)
 
     // The first polyline in the document has a number of points to draw arcs,
     // the last one jumps back to the start, so we call "end" the last but one.
-    sal_Int32 nFirstEnd = getXPath(pXmlDoc, "(//polyline)[1]/point[last()-1]"_ostr, "x"_ostr).toInt32();
+    sal_Int32 nFirstEnd = getXPath(pXmlDoc, "(//polyline)[1]/point[last()-1]", "x").toInt32();
     // The second polyline has a different start point, but the arc it draws
     // should end at the ~same position as the first polyline.
-    sal_Int32 nSecondEnd = getXPath(pXmlDoc, "(//polyline)[2]/point[last()]"_ostr, "x"_ostr).toInt32();
+    sal_Int32 nSecondEnd = getXPath(pXmlDoc, "(//polyline)[2]/point[last()]", "x").toInt32();
 
     // nFirstEnd was 6023 and nSecondEnd was 6648, now they should be much closer, e.g. nFirstEnd = 6550, nSecondEnd = 6548
     OString aMsg = "nFirstEnd is " + OString::number(nFirstEnd) + ", nSecondEnd is " + OString::number(nSecondEnd);
@@ -1873,8 +1851,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testFdo87448)
 CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testTextCursorInvalidation)
 {
     createSwDoc();
-    SwDoc* pDoc = getSwDoc();
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
     uno::Reference<beans::XPropertySet> xPageStyle(getStyles(u"PageStyles"_ustr)->getByName(u"Standard"_ustr), uno::UNO_QUERY);
     CPPUNIT_ASSERT(xPageStyle.is());
     xPageStyle->setPropertyValue(u"HeaderIsOn"_ustr, uno::Any(true));
@@ -1897,8 +1874,9 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testTdf68183)
     // First disable RSID and check if indeed no such attribute is inserted.
     createSwDoc();
     SwDoc* pDoc = getSwDoc();
-    SW_MOD()->GetModuleConfig()->SetStoreRsid(false);
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    SwModule* mod = SwModule::get();
+    mod->GetModuleConfig()->SetStoreRsid(false);
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
     pWrtShell->Insert2(u"X"_ustr);
 
     SwNodeIndex aIdx(pDoc->GetNodes().GetEndOfContent(), -1);
@@ -1907,7 +1885,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testTdf68183)
     CPPUNIT_ASSERT_EQUAL(false, pTextNode->GetSwAttrSet().HasItem(RES_PARATR_RSID));
 
     // Then enable storing of RSID and make sure that the attribute is inserted.
-    SW_MOD()->GetModuleConfig()->SetStoreRsid(true);
+    mod->GetModuleConfig()->SetStoreRsid(true);
 
     pWrtShell->DelToStartOfLine();
     pWrtShell->Insert2(u"X"_ustr);
@@ -1922,7 +1900,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testCp1000115)
     // This was 1: the long paragraph in the B1 cell did flow over to the
     // second page, so there was only one paragraph in the second cell of the
     // second page.
-    assertXPath(pXmlDoc, "/root/page[2]/body/tab/row/cell[2]/txt"_ostr, 2);
+    assertXPath(pXmlDoc, "/root/page[2]/body/tab/row/cell[2]/txt", 2);
 }
 
 CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testTdf63214)
@@ -1930,7 +1908,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testTdf63214)
     //This is a crash test
     createSwDoc();
     SwDoc* pDoc = getSwDoc();
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
     sw::UndoManager& rUndoManager = pDoc->GetUndoManager();
     pWrtShell->Insert(u"V"_ustr);
     {   //limiting the lifetime of SwPaM with a nested scope
@@ -1960,14 +1938,14 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testTdf90003)
     CPPUNIT_ASSERT(pXmlDoc);
     // This was 1: an unexpected fly portion was created, resulting in too
     // large x position for the empty paragraph marker.
-    assertXPath(pXmlDoc, "//SwFixPortion[@type='PortionType::Fly']"_ostr, 0);
+    assertXPath(pXmlDoc, "//SwFixPortion[@type='PortionType::Fly']", 0);
 }
 
 CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testTdf51741)
 {
     createSwDoc();
     SwDoc* pDoc = getSwDoc();
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
     sw::UndoManager& rUndoManager = pDoc->GetUndoManager();
     IDocumentMarkAccess* const pMarkAccess = pDoc->getIDocumentMarkAccess();
     SwPaM aPaM( SwNodeIndex(pDoc->GetNodes().GetEndOfContent(), -1) );
@@ -1987,7 +1965,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testTdf51741)
     CPPUNIT_ASSERT(pWrtShell->IsModified());
     pWrtShell->ResetModified();
     CPPUNIT_ASSERT_EQUAL(sal_Int32(1), pMarkAccess->getAllMarksCount());
-    IDocumentMarkAccess::const_iterator_t ppBkmk = pMarkAccess->findMark(u"Mark"_ustr);
+    auto ppBkmk = pMarkAccess->findMark(u"Mark"_ustr);
     CPPUNIT_ASSERT(ppBkmk != pMarkAccess->getAllMarksEnd());
     //Modification 4
     pMarkAccess->renameMark(*ppBkmk, u"Mark_"_ustr);
@@ -2055,7 +2033,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testDeleteTableRedlines)
 {
     createSwDoc();
     SwDoc* pDoc = getSwDoc();
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
     SwInsertTableOptions TableOpt(SwInsertTableFlags::DefaultBorder, 0);
     const SwTable& rTable = pWrtShell->InsertTable(TableOpt, 1, 3);
     uno::Reference<text::XTextTable> xTable(getParagraphOrTable(1), uno::UNO_QUERY);
@@ -2074,8 +2052,7 @@ CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testDeleteTableRedlines)
 CPPUNIT_TEST_FIXTURE(SwUiWriterTest, testXFlatParagraph)
 {
     createSwDoc();
-    SwDoc* pDoc = getSwDoc();
-    SwWrtShell* pWrtShell = pDoc->GetDocShell()->GetWrtShell();
+    SwWrtShell* pWrtShell = getSwDocShell()->GetWrtShell();
     //Inserting some text in the document
     pWrtShell->Insert(u"This is sample text"_ustr);
     pWrtShell->SplitNode();
