@@ -46,7 +46,7 @@
 
 // constructor for default item in attribute-pool
 SwFormatField::SwFormatField( sal_uInt16 nWhich )
-    : SfxPoolItem( nWhich, SfxItemType::SwFormatFieldType )
+    : SfxPoolItem( nWhich )
     , SfxBroadcaster()
     , mpTextField( nullptr )
 {
@@ -54,7 +54,7 @@ SwFormatField::SwFormatField( sal_uInt16 nWhich )
 }
 
 SwFormatField::SwFormatField( const SwField &rField )
-    : SfxPoolItem( RES_TXTATR_FIELD, SfxItemType::SwFormatFieldType )
+    : SfxPoolItem( RES_TXTATR_FIELD )
     , SfxBroadcaster()
     , mpField( rField.CopyField() )
     , mpTextField( nullptr )
@@ -218,8 +218,7 @@ SwFormatField* SwFormatField::Clone( SfxItemPool* ) const
 
 void SwFormatField::InvalidateField()
 {
-    const SwPtrMsgPoolItem aItem(RES_REMOVE_UNO_OBJECT, &static_cast<sw::BroadcastingModify&>(*this));
-    CallSwClientNotify(sw::LegacyModifyHint{ &aItem, &aItem });
+    CallSwClientNotify(sw::RemoveUnoObjectHint(this));
 }
 
 void SwFormatField::SwClientNotify( const SwModify& rModify, const SfxHint& rHint )
@@ -250,7 +249,7 @@ void SwFormatField::SwClientNotify( const SwModify& rModify, const SfxHint& rHin
         rDoc.getIDocumentContentOperations().DeleteRange( *pPaM );
         rDoc.getIDocumentContentOperations().InsertString( *pPaM, aEntry );
     }
-    else if (rHint.GetId() == SfxHintId::SwLegacyModify)
+    else if (rHint.GetId() == SfxHintId::SwLegacyModify || rHint.GetId() == SfxHintId::SwFormatChange)
     {
         if(!mpTextField)
             return;
@@ -404,6 +403,27 @@ void SwFormatField::UpdateDocPos(const SwTwips nDocPos)
 }
 void SwFormatField::UpdateTextNode(const SfxHint& rHint)
 {
+    if(SfxHintId::SwRemoveUnoObject == rHint.GetId())
+    {   // invalidate cached UNO object
+        m_wXTextField.clear();
+        // ??? why does this Modify method not already do this?
+        CallSwClientNotify(rHint);
+        return;
+    }
+    if (rHint.GetId() == SfxHintId::SwFormatChange)
+    {
+        auto pChangeHint = static_cast<const SwFormatChangeHint*>(&rHint);
+        if (!IsFieldInDoc())
+            return;
+
+        SwTextNode* pTextNd = &mpTextField->GetTextNode();
+        OSL_ENSURE(pTextNd, "Where is my Node?");
+
+        bool bTriggerNode = pChangeHint->m_pNewFormat != nullptr;
+        if(bTriggerNode)
+            pTextNd->TriggerNodeUpdate(*pChangeHint);
+        return;
+    }
     if(SfxHintId::SwLegacyModify != rHint.GetId())
         return;
     auto pLegacy = static_cast<const sw::LegacyModifyHint*>(&rHint);
@@ -414,13 +434,6 @@ void SwFormatField::UpdateTextNode(const SfxHint& rHint)
         ForceUpdateTextNode();
         return;
     }
-    else if (pOld && (RES_REMOVE_UNO_OBJECT == pOld->Which()))
-    {   // invalidate cached UNO object
-        m_wXTextField.clear();
-        // ??? why does this Modify method not already do this?
-        CallSwClientNotify(sw::LegacyModifyHint(pOld, pNew));
-        return;
-    }
 
     if (!IsFieldInDoc())
         return;
@@ -439,7 +452,6 @@ void SwFormatField::UpdateTextNode(const SfxHint& rHint)
         switch(pNew->Which())
         {
         case RES_ATTRSET_CHG:
-        case RES_FMT_CHG:
             break;
         default:
             {
