@@ -252,7 +252,7 @@ void SwDocShell::Notify( SfxBroadcaster&, const SfxHint& rHint )
             case SfxEventHintId::OpenDoc:
             {
                 uno::Sequence< css::uno::Any > aArgs;
-                SW_MOD()->CallAutomationApplicationEventSinks( u"DocumentChange"_ustr, aArgs );
+                SwModule::get()->CallAutomationApplicationEventSinks(u"DocumentChange"_ustr, aArgs);
                 break;
             }
             default:
@@ -266,7 +266,7 @@ void SwDocShell::Notify( SfxBroadcaster&, const SfxHint& rHint )
                     uno::Any aDocument;
                     aDocument <<= mxAutomationDocumentObject;
                     uno::Sequence< uno::Any > aArgs{ aDocument };
-                    SW_MOD()->CallAutomationApplicationEventSinks( u"NewDocument"_ustr, aArgs );
+                    SwModule::get()->CallAutomationApplicationEventSinks( u"NewDocument"_ustr, aArgs );
                 }
                 break;
             case SfxEventHintId::OpenDoc:
@@ -274,7 +274,7 @@ void SwDocShell::Notify( SfxBroadcaster&, const SfxHint& rHint )
                     uno::Any aDocument;
                     aDocument <<= mxAutomationDocumentObject;
                     uno::Sequence< uno::Any > aArgs{ aDocument };
-                    SW_MOD()->CallAutomationApplicationEventSinks( u"DocumentOpen"_ustr, aArgs );
+                    SwModule::get()->CallAutomationApplicationEventSinks( u"DocumentOpen"_ustr, aArgs );
                 }
                 break;
             default:
@@ -365,7 +365,7 @@ bool SwDocShell::PrepareClose( bool bUI )
                                        uno::Any(false)
         };
 
-        SW_MOD()->CallAutomationApplicationEventSinks( u"DocumentBeforeClose"_ustr, aArgs );
+        SwModule::get()->CallAutomationApplicationEventSinks(u"DocumentBeforeClose"_ustr, aArgs);
 
         // If the Cancel argument was set to True by an event handler, return false.
         bool bCancel(false);
@@ -569,7 +569,7 @@ void SwDocShell::Execute(SfxRequest& rReq)
                         while( pFlt )
                         {
                             // --> OD #i117339#
-                            if( pFlt && pFlt->IsAllowedAsTemplate() &&
+                            if( pFlt->IsAllowedAsTemplate() &&
                                 ( pFlt->GetUserData() == "CXML" ||
                                   pFlt->GetUserData() == "CXMLV" ) )
                             {
@@ -776,7 +776,7 @@ void SwDocShell::Execute(SfxRequest& rReq)
                             ErrCodeMsg eErr = aWrt.Write( xWrt );
                             if( !eErr.IgnoreWarning() )
                             {
-                                uno::Reference< uno::XComponentContext > xContext = ::comphelper::getProcessComponentContext();
+                                const uno::Reference< uno::XComponentContext >& xContext = ::comphelper::getProcessComponentContext();
                                 uno::Reference< frame::XDispatchProvider > xProv = drawing::ModuleDispatcher::create( xContext );
 
                                 uno::Reference< frame::XDispatchHelper > xHelper( frame::DispatchHelper::create(xContext) );
@@ -834,7 +834,7 @@ void SwDocShell::Execute(SfxRequest& rReq)
                     pStrm->Seek( STREAM_SEEK_TO_BEGIN );
                     if ( nWhich == FN_OUTLINE_TO_IMPRESS )
                     {
-                        uno::Reference< uno::XComponentContext > xContext = ::comphelper::getProcessComponentContext();
+                        const uno::Reference< uno::XComponentContext >& xContext = ::comphelper::getProcessComponentContext();
                         uno::Reference< frame::XDispatchProvider > xProv = drawing::ModuleDispatcher::create( xContext );
 
                         uno::Reference< frame::XDispatchHelper > xHelper( frame::DispatchHelper::create(xContext) );
@@ -1544,9 +1544,8 @@ void SwDocShell::ReloadFromHtml( const OUString& rStreamName, SwSrcView* pSrcVie
     RemoveLink();
 
     // now also the UNO-Model has to be informed about the new Doc #51535#
-    uno::Reference<text::XTextDocument> xDoc(GetBaseModel(), uno::UNO_QUERY);
-    text::XTextDocument* pxDoc = xDoc.get();
-    static_cast<SwXTextDocument*>(pxDoc)->InitNewDoc();
+    rtl::Reference<SwXTextDocument> xDoc(GetBaseModel());
+    xDoc->InitNewDoc();
 
     AddLink();
     //#116402# update font list when new document is created
