@@ -171,9 +171,11 @@ private:
     void DeInitGraphics();
 
 public:
-    // Return HFONT, and whether the font is for vertical writing ( prefixed with '@' )
+    // Returns base HFONT, an optional HFONT for non-rotated CJK glyphs,
     // and tmDescent value for adjusting offset in vertical writing mode.
-    std::tuple<HFONT,bool,sal_Int32> ImplDoSetFont(HDC hDC, vcl::font::FontSelectPattern const & i_rFont, const vcl::font::PhysicalFontFace * i_pFontFace, HFONT& o_rOldFont);
+    std::tuple<HFONT, HFONT, sal_Int32>
+    ImplDoSetFont(HDC hDC, vcl::font::FontSelectPattern const& i_rFont,
+                  const vcl::font::PhysicalFontFace* i_pFontFace, HFONT& o_rOldFont);
 
     HDC getHDC() const { return mhLocalDC; }
     // NOTE: this doesn't transfer ownership! See class comment.
