@@ -28,7 +28,8 @@ class WinSalMenu : public SalMenu
 public:
     WinSalMenu();
     virtual ~WinSalMenu() override;
-    virtual bool HasNativeMenuBar() override;
+    virtual bool VisibleMenuBar() override;  // must return TRUE to actually DISPLAY native menu bars
+                            // otherwise only menu messages are processed (eg, OLE on Windows)
 
     virtual void InsertItem( SalMenuItem* pSalMenuItem, unsigned nPos ) override;
     virtual void RemoveItem( unsigned nPos ) override;
@@ -39,7 +40,7 @@ public:
     virtual void SetItemText( unsigned nPos, SalMenuItem* pSalMenuItem, const OUString& rText ) override;
     virtual void SetItemImage( unsigned nPos, SalMenuItem* pSalMenuItem, const Image& rImage ) override;
     virtual void SetAccelerator( unsigned nPos, SalMenuItem* pSalMenuItem, const vcl::KeyCode& rKeyCode, const OUString& rKeyName ) override;
-    virtual void GetSystemMenuData( SystemMenuData* pData ) override;
+    virtual void GetSystemMenuData(SystemMenuData& rData) override;
 
     HMENU mhMenu;           // the menu handle
     bool  mbMenuBar;        // true for menu bars
