@@ -40,6 +40,7 @@
 #include <hb-ot.h>
 #include <hb-graphite2.h>
 #include <hb-icu.h>
+#include <hb-aat.h>
 
 #include <map>
 #include <memory>
@@ -248,24 +249,22 @@ void GenericSalLayout::SetNeedFallback(vcl::text::ImplLayoutArgs& rArgs, sal_Int
     if (nCharPos < 0 || nCharPos == nCharEnd || mbFuzzing)
         return;
 
-    using namespace ::com::sun::star;
-
     if (!mxBreak.is())
         mxBreak = vcl::unohelper::CreateBreakIterator();
 
-    lang::Locale aLocale(rArgs.maLanguageTag.getLocale());
+    const css::lang::Locale& rLocale(rArgs.maLanguageTag.getLocale());
 
     //if position nCharPos is missing in the font, grab the entire grapheme and
     //mark all glyphs as missing so the whole thing is rendered with the same
     //font
     sal_Int32 nDone;
-    int nGraphemeEndPos = mxBreak->nextCharacters(rArgs.mrStr, nCharEnd - 1, aLocale,
-                                                  i18n::CharacterIteratorMode::SKIPCELL, 1, nDone);
+    int nGraphemeEndPos = mxBreak->nextCharacters(rArgs.mrStr, nCharEnd - 1, rLocale,
+                                                  css::i18n::CharacterIteratorMode::SKIPCELL, 1, nDone);
     // Safely advance nCharPos in case it is a non-BMP character.
     rArgs.mrStr.iterateCodePoints(&nCharPos);
     int nGraphemeStartPos =
-        mxBreak->previousCharacters(rArgs.mrStr, nCharPos, aLocale,
-            i18n::CharacterIteratorMode::SKIPCELL, 1, nDone);
+        mxBreak->previousCharacters(rArgs.mrStr, nCharPos, rLocale,
+            css::i18n::CharacterIteratorMode::SKIPCELL, 1, nDone);
 
     // tdf#107612
     // If the start of the fallback run is Mongolian character and the previous
@@ -386,6 +385,14 @@ bool GenericSalLayout::LayoutText(vcl::text::ImplLayoutArgs& rArgs, const SalLay
     hb_font_t *pHbFont = GetFont().GetHbFont();
     bool isGraphite = GetFont().IsGraphiteFont();
 
+    // tdf#163215: Identify layouts that don't have strict kashida position validation.
+    m_bHasFontKashidaPositions = false;
+    if (!(rArgs.mnFlags & SalLayoutFlags::DisableKashidaValidation))
+    {
+        hb_face_t* pHbFace = hb_font_get_face(pHbFont);
+        m_bHasFontKashidaPositions = !hb_aat_layout_has_substitution(pHbFace);
+    }
+
     int nGlyphCapacity = 2 * (rArgs.mnEndCharPos - rArgs.mnMinCharPos);
     m_GlyphItems.reserve(nGlyphCapacity);
 
@@ -449,7 +456,7 @@ bool GenericSalLayout::LayoutText(vcl::text::ImplLayoutArgs& rArgs, const SalLay
     double nYScale = 0;
     GetFont().GetScale(&nXScale, &nYScale);
 
-    basegfx::B2DPoint aCurrPos(0, 0);
+    double nCurrX = 0.0;
     while (true)
     {
         int nBidiMinRunPos, nBidiEndRunPos;
@@ -760,7 +767,9 @@ bool GenericSalLayout::LayoutText(vcl::text::ImplLayoutArgs& rArgs, const SalLay
                 if (hb_glyph_info_get_glyph_flags(&pHbGlyphInfos[i]) & HB_GLYPH_FLAG_UNSAFE_TO_BREAK)
                     nGlyphFlags |= GlyphItemFlags::IS_UNSAFE_TO_BREAK;
 
-                if (hb_glyph_info_get_glyph_flags(&pHbGlyphInfos[i]) & HB_GLYPH_FLAG_SAFE_TO_INSERT_TATWEEL)
+                if (!m_bHasFontKashidaPositions
+                    || (hb_glyph_info_get_glyph_flags(&pHbGlyphInfos[i])
+                        & HB_GLYPH_FLAG_SAFE_TO_INSERT_TATWEEL))
                     nGlyphFlags |= GlyphItemFlags::IS_SAFE_TO_INSERT_KASHIDA;
 
                 double nAdvance, nXOffset, nYOffset;
@@ -802,7 +811,7 @@ bool GenericSalLayout::LayoutText(vcl::text::ImplLayoutArgs& rArgs, const SalLay
                     nYOffset = std::round(nYOffset);
                 }
 
-                basegfx::B2DPoint aNewPos(aCurrPos.getX() + nXOffset, aCurrPos.getY() + nYOffset);
+                basegfx::B2DPoint aNewPos(nCurrX + nXOffset, nYOffset);
                 const GlyphItem aGI(nCharPos, nCharCount, nGlyphIndex, aNewPos, nGlyphFlags,
                                     nAdvance, nXOffset, nYOffset, nOrigCharPos);
 
@@ -816,7 +825,7 @@ bool GenericSalLayout::LayoutText(vcl::text::ImplLayoutArgs& rArgs, const SalLay
                 if (nLowerBound >= rArgs.mnDrawOriginCluster
                     && nUpperBound < rArgs.mnDrawEndCharPos)
                 {
-                    aCurrPos.adjustX(nAdvance);
+                    nCurrX += nAdvance;
                 }
             }
         }
@@ -844,7 +853,7 @@ void GenericSalLayout::GetCharWidths(std::vector<double>& rCharWidths, const OUS
     rCharWidths.resize(nCharCount, 0);
 
     css::uno::Reference<css::i18n::XBreakIterator> xBreak;
-    auto aLocale(maLanguageTag.getLocale());
+    const css::lang::Locale& rLocale(maLanguageTag.getLocale());
 
     for (auto const& aGlyphItem : m_GlyphItems)
     {
@@ -864,7 +873,7 @@ void GenericSalLayout::GetCharWidths(std::vector<double>& rCharWidths, const OUS
             sal_Int32 nPos = aGlyphItem.charPos();
             while (nPos < aGlyphItem.charPos() + aGlyphItem.charCount())
             {
-                nPos = xBreak->nextCharacters(rStr, nPos, aLocale,
+                nPos = xBreak->nextCharacters(rStr, nPos, rLocale,
                     css::i18n::CharacterIteratorMode::SKIPCELL, 1, nDone);
                 nGraphemeCount++;
             }
@@ -925,7 +934,7 @@ void GenericSalLayout::GetCharWidths(std::vector<double>& rCharWidths, const OUS
             for (auto nWidth : aWidths)
             {
                 rCharWidths[nPos - mnMinCharPos] += nWidth;
-                nPos = xBreak->nextCharacters(rStr, nPos, aLocale,
+                nPos = xBreak->nextCharacters(rStr, nPos, rLocale,
                     css::i18n::CharacterIteratorMode::SKIPCELL, 1, nDone);
             }
         }
@@ -1010,8 +1019,8 @@ void GenericSalLayout::ApplyJustificationData(const JustificationData& rstJustif
 
             // Adjust the X position of the rest of the glyphs in the cluster.
             // We iterate backwards since this is an RTL glyph.
-            for (int j = i - 1; j >= 0 && m_GlyphItems[j].IsInCluster(); j--)
-                m_GlyphItems[j].adjustLinearPosX(nDelta + nDiff);
+            for (size_t j = i; j >= 1 && m_GlyphItems[j - 1].IsInCluster(); --j)
+                m_GlyphItems[j - 1].adjustLinearPosX(nDelta + nDiff);
 
             // This is a Kashida insertion position, mark it. Kashida glyphs
             // will be inserted below.
@@ -1088,27 +1097,34 @@ void GenericSalLayout::ApplyJustificationData(const JustificationData& rstJustif
     }
 }
 
+bool GenericSalLayout::HasFontKashidaPositions() const { return m_bHasFontKashidaPositions; }
+
 // Kashida will be inserted between nCharPos and nNextCharPos.
 bool GenericSalLayout::IsKashidaPosValid(int nCharPos, int nNextCharPos) const
 {
     // Search for glyph items corresponding to nCharPos and nNextCharPos.
-    auto const& rGlyph = std::find_if(m_GlyphItems.begin(), m_GlyphItems.end(),
+    auto const aGlyph = std::find_if(m_GlyphItems.begin(), m_GlyphItems.end(),
                                       [&](const GlyphItem& g) { return g.charPos() == nCharPos; });
-    auto const& rNextGlyph = std::find_if(m_GlyphItems.begin(), m_GlyphItems.end(),
+    auto const aNextGlyph = std::find_if(m_GlyphItems.begin(), m_GlyphItems.end(),
                                           [&](const GlyphItem& g) { return g.charPos() == nNextCharPos; });
 
     // If either is not found then a ligature is created at this position, we
     // can’t insert Kashida here.
-    if (rGlyph == m_GlyphItems.end() || rNextGlyph == m_GlyphItems.end())
+    if (aGlyph == m_GlyphItems.end() || aNextGlyph == m_GlyphItems.end())
         return false;
 
     // If the either character is not supported by this layout, return false so
     // that fallback layouts would be checked for it.
-    if (rGlyph->glyphId() == 0 || rNextGlyph->glyphId() == 0)
+    if (aGlyph->glyphId() == 0 || aNextGlyph->glyphId() == 0)
         return false;
 
     // Lastly check if this position is kashida-safe.
-    return rNextGlyph->IsSafeToInsertKashida();
+    return aNextGlyph->IsSafeToInsertKashida();
+}
+
+void GenericSalLayout::drawSalLayout(void* pSurface, const basegfx::BColor& rTextColor, bool bAntiAliased) const
+{
+    Application::GetDefaultDevice()->GetGraphics()->DrawSalLayout(*this, pSurface, rTextColor, bAntiAliased);
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
