@@ -20,7 +20,6 @@
 #include <com/sun/star/drawing/XShape.hpp>
 #include <com/sun/star/style/XStyleFamiliesSupplier.hpp>
 
-#include <officecfg/Office/Common.hxx>
 #include <rtl/character.hxx>
 #include <unotools/saveopt.hxx>
 
@@ -81,7 +80,7 @@ struct XmlFont
     }
 };
 
-Color asColor(com::sun::star::rendering::RGBColor const& rRGBColor)
+Color asColor(css::rendering::RGBColor const& rRGBColor)
 {
     basegfx::BColor aBColor(rRGBColor.Red, rRGBColor.Green, rRGBColor.Blue);
     return Color(aBColor);
@@ -91,15 +90,15 @@ Color asColor(com::sun::star::rendering::RGBColor const& rRGBColor)
 CPPUNIT_TEST_FIXTURE(XmloffStyleTest, testFontSorting)
 {
     // Given an empty document with default fonts (Liberation Sans, Lucida Sans, etc):
-    mxComponent = loadFromDesktop(u"private:factory/swriter"_ustr);
+    loadFromURL(u"private:factory/swriter"_ustr);
 
     // When saving that document to ODT:
     save(u"writer8"_ustr);
 
     // Then make sure <style:font-face> elements are sorted (by style:name="..."):
     xmlDocUniquePtr pXmlDoc = parseExport(u"content.xml"_ustr);
-    xmlXPathObjectPtr pXPath = getXPathNode(
-        pXmlDoc, "/office:document-content/office:font-face-decls/style:font-face"_ostr);
+    xmlXPathObjectPtr pXPath
+        = getXPathNode(pXmlDoc, "/office:document-content/office:font-face-decls/style:font-face");
     xmlNodeSetPtr pXmlNodes = pXPath->nodesetval;
     int nNodeCount = xmlXPathNodeSetGetLength(pXmlNodes);
     std::vector<XmlFont> aXMLFonts;
@@ -171,45 +170,34 @@ CPPUNIT_TEST_FIXTURE(XmloffStyleTest, testRtlGutter)
 
 CPPUNIT_TEST_FIXTURE(XmloffStyleTest, testWritingModeBTLR)
 {
+    Resetter resetter([]() { SetODFDefaultVersion(SvtSaveOptions::ODFVER_LATEST); });
+
     // Load document. It has a frame style with writing-mode bt-lr.
     // In ODF 1.3 extended it is written as loext:writing-mode="bt-lr".
     // In ODF 1.3 strict, there must not be an attribute at all.
     loadFromFile(u"tdf150407_WritingModeBTLR_style.odt");
 
-    Resetter _([]() {
-        std::shared_ptr<comphelper::ConfigurationChanges> pBatch(
-            comphelper::ConfigurationChanges::create());
-        officecfg::Office::Common::Save::ODF::DefaultVersion::set(3, pBatch);
-        return pBatch->commit();
-    });
-
-    // Save to ODF 1.3 extended. Adapt 3 (=ODFVER_LATEST) to a to be ODFVER_013_EXTENDED when
-    // attribute value "bt-lr" is included in ODF strict.
+    // Save to latest extended. Adapt test, when attribute value "bt-lr" is included in ODF strict.
     {
-        std::shared_ptr<comphelper::ConfigurationChanges> pBatch(
-            comphelper::ConfigurationChanges::create());
-        officecfg::Office::Common::Save::ODF::DefaultVersion::set(3, pBatch);
-        pBatch->commit();
         save(u"writer8"_ustr);
 
         // With applied fix for tdf150407 still loext:writing-mode="bt-lr" has to be written.
         xmlDocUniquePtr pXmlDoc = parseExport(u"styles.xml"_ustr);
         assertXPath(pXmlDoc,
                     "/office:document-styles/office:styles/style:style[@style:name='FrameBTLR']/"
-                    "style:graphic-properties[@loext:writing-mode]"_ostr);
+                    "style:graphic-properties[@loext:writing-mode]");
         assertXPath(pXmlDoc,
                     "/office:document-styles/office:styles/style:style[@style:name='FrameBTLR']/"
-                    "style:graphic-properties"_ostr,
-                    "writing-mode"_ostr, u"bt-lr"_ustr);
+                    "style:graphic-properties",
+                    "writing-mode", u"bt-lr");
     }
 
     loadFromFile(u"tdf150407_WritingModeBTLR_style.odt");
     // Save to ODF 1.3 strict.
     {
-        std::shared_ptr<comphelper::ConfigurationChanges> pBatch(
-            comphelper::ConfigurationChanges::create());
-        officecfg::Office::Common::Save::ODF::DefaultVersion::set(10, pBatch);
-        pBatch->commit();
+        SetODFDefaultVersion(SvtSaveOptions::ODFDefaultVersion::ODFVER_013);
+        // As of Nov 2024, validating against a version other than LATEST is not implemented.
+        skipValidation();
         save(u"writer8"_ustr);
 
         // Without the fix an faulty 'writing-mode="bt-lr"' attribute was written in productive build.
@@ -217,32 +205,23 @@ CPPUNIT_TEST_FIXTURE(XmloffStyleTest, testWritingModeBTLR)
         xmlDocUniquePtr pXmlDoc = parseExport(u"styles.xml"_ustr);
         assertXPathNoAttribute(pXmlDoc,
                                "/office:document-styles/office:styles/"
-                               "style:style[@style:name='FrameBTLR']/style:graphic-properties"_ostr,
-                               "writing-mode"_ostr);
+                               "style:style[@style:name='FrameBTLR']/style:graphic-properties",
+                               "writing-mode");
     }
 }
 
 CPPUNIT_TEST_FIXTURE(XmloffStyleTest, testPosRelBottomMargin)
 {
+    Resetter resetter([]() { SetODFDefaultVersion(SvtSaveOptions::ODFVER_LATEST); });
+
     // Load document. It has a frame position with vertical position relative to bottom margin.
     // In ODF 1.3 extended it is written as loext:vertical-rel="page-content-bottom".
     // In ODF 1.3 strict, there must not be an attribute at all.
     loadFromFile(u"tdf150407_PosRelBottomMargin.docx");
 
-    Resetter _([]() {
-        std::shared_ptr<comphelper::ConfigurationChanges> pBatch(
-            comphelper::ConfigurationChanges::create());
-        officecfg::Office::Common::Save::ODF::DefaultVersion::set(3, pBatch);
-        return pBatch->commit();
-    });
-
     // Save to ODF 1.3 extended. Adapt 3 (=ODFVER_LATEST) to a to be ODFVER_013_EXTENDED when
     // attribute value "page-content-bottom" is included in ODF strict.
     {
-        std::shared_ptr<comphelper::ConfigurationChanges> pBatch(
-            comphelper::ConfigurationChanges::create());
-        officecfg::Office::Common::Save::ODF::DefaultVersion::set(3, pBatch);
-        pBatch->commit();
         save(u"writer8"_ustr);
 
         // With applied fix for tdf150407 still loext:vertical-rel="page-content-bottom" has to be
@@ -251,21 +230,18 @@ CPPUNIT_TEST_FIXTURE(XmloffStyleTest, testPosRelBottomMargin)
         assertXPath(
             pXmlDoc,
             "/office:document-content/office:automatic-styles/style:style[@style:name='gr1']/"
-            "style:graphic-properties[@loext:vertical-rel]"_ostr);
+            "style:graphic-properties[@loext:vertical-rel]");
         assertXPath(
             pXmlDoc,
             "/office:document-content/office:automatic-styles/style:style[@style:name='gr1']/"
-            "style:graphic-properties"_ostr,
-            "vertical-rel"_ostr, u"page-content-bottom"_ustr);
+            "style:graphic-properties",
+            "vertical-rel", u"page-content-bottom");
     }
 
     loadFromFile(u"tdf150407_PosRelBottomMargin.docx");
     // Save to ODF 1.3 strict.
     {
-        std::shared_ptr<comphelper::ConfigurationChanges> pBatch(
-            comphelper::ConfigurationChanges::create());
-        officecfg::Office::Common::Save::ODF::DefaultVersion::set(10, pBatch);
-        pBatch->commit();
+        SetODFDefaultVersion(SvtSaveOptions::ODFDefaultVersion::ODFVER_013);
         save(u"writer8"_ustr);
 
         // Without the fix an faulty 'vertical-rel="page-content-bottom"' attribute was written in
@@ -273,32 +249,23 @@ CPPUNIT_TEST_FIXTURE(XmloffStyleTest, testPosRelBottomMargin)
         xmlDocUniquePtr pXmlDoc = parseExport(u"content.xml"_ustr);
         assertXPathNoAttribute(pXmlDoc,
                                "/office:document-content/office:automatic-styles/"
-                               "style:style[@style:name='gr1']/style:graphic-properties"_ostr,
-                               "vertical-rel"_ostr);
+                               "style:style[@style:name='gr1']/style:graphic-properties",
+                               "vertical-rel");
     }
 }
 
 CPPUNIT_TEST_FIXTURE(XmloffStyleTest, testPosRelTopMargin)
 {
+    Resetter resetter([]() { SetODFDefaultVersion(SvtSaveOptions::ODFVER_LATEST); });
+
     // Load document. It has a frame position with vertical position relative to top margin.
     // In ODF 1.3 extended it is written as loext:vertical-rel="page-content-top".
     // In ODF 1.3 strict, there must not be an attribute at all.
     loadFromFile(u"tdf150407_PosRelTopMargin.docx");
 
-    Resetter _([]() {
-        std::shared_ptr<comphelper::ConfigurationChanges> pBatch(
-            comphelper::ConfigurationChanges::create());
-        officecfg::Office::Common::Save::ODF::DefaultVersion::set(3, pBatch);
-        return pBatch->commit();
-    });
-
     // Save to ODF 1.3 extended. Adapt 3 (=ODFVER_LATEST) to a to be ODFVER_013_EXTENDED when
     // attribute value "page-content-top" is included in ODF strict.
     {
-        std::shared_ptr<comphelper::ConfigurationChanges> pBatch(
-            comphelper::ConfigurationChanges::create());
-        officecfg::Office::Common::Save::ODF::DefaultVersion::set(3, pBatch);
-        pBatch->commit();
         save(u"writer8"_ustr);
 
         // With applied fix for tdf150407 still loext:vertical-rel="page-content-top has to be
@@ -307,21 +274,18 @@ CPPUNIT_TEST_FIXTURE(XmloffStyleTest, testPosRelTopMargin)
         assertXPath(
             pXmlDoc,
             "/office:document-content/office:automatic-styles/style:style[@style:name='gr1']/"
-            "style:graphic-properties[@loext:vertical-rel]"_ostr);
+            "style:graphic-properties[@loext:vertical-rel]");
         assertXPath(
             pXmlDoc,
             "/office:document-content/office:automatic-styles/style:style[@style:name='gr1']/"
-            "style:graphic-properties"_ostr,
-            "vertical-rel"_ostr, u"page-content-top"_ustr);
+            "style:graphic-properties",
+            "vertical-rel", u"page-content-top");
     }
 
     loadFromFile(u"tdf150407_PosRelTopMargin.docx");
     // Save to ODF 1.3 strict.
     {
-        std::shared_ptr<comphelper::ConfigurationChanges> pBatch(
-            comphelper::ConfigurationChanges::create());
-        officecfg::Office::Common::Save::ODF::DefaultVersion::set(10, pBatch);
-        pBatch->commit();
+        SetODFDefaultVersion(SvtSaveOptions::ODFDefaultVersion::ODFVER_013);
         save(u"writer8"_ustr);
 
         // Without the fix an faulty 'vertical-rel="page-content-top"' attribute was written in
@@ -329,11 +293,36 @@ CPPUNIT_TEST_FIXTURE(XmloffStyleTest, testPosRelTopMargin)
         xmlDocUniquePtr pXmlDoc = parseExport(u"content.xml"_ustr);
         assertXPathNoAttribute(pXmlDoc,
                                "/office:document-content/office:automatic-styles/"
-                               "style:style[@style:name='gr1']/style:graphic-properties"_ostr,
-                               "vertical-rel"_ostr);
+                               "style:style[@style:name='gr1']/style:graphic-properties",
+                               "vertical-rel");
     }
 }
 
+CPPUNIT_TEST_FIXTURE(XmloffStyleTest, testTdf156707)
+{
+    // The file contains a shape with linear gradient fill from red #ff0000 to yellow #ffff00,
+    // named 'red2yellow'
+    loadFromFile(u"tdf156707_text_form_control_borders.odt");
+    saveAndReload(u"writer8"_ustr);
+
+    uno::Reference<drawing::XShape> xShape = getShape(0);
+    uno::Reference<beans::XPropertySet> xShapeProperties(xShape, uno::UNO_QUERY_THROW);
+
+    sal_uInt16 nBorderStyle = 0; // 0 = none, 1 = 3d [default], 2 = flat
+    xShapeProperties->getPropertyValue(u"ControlBorder"_ustr) >>= nBorderStyle;
+    CPPUNIT_ASSERT_EQUAL(sal_uInt16(2), nBorderStyle);
+
+    xShape = getShape(1);
+    xShapeProperties.set(xShape, uno::UNO_QUERY_THROW);
+    xShapeProperties->getPropertyValue(u"ControlBorder"_ustr) >>= nBorderStyle;
+    CPPUNIT_ASSERT_EQUAL(sal_uInt16(1), nBorderStyle);
+
+    xShape = getShape(2);
+    xShapeProperties.set(xShape, uno::UNO_QUERY_THROW);
+    xShapeProperties->getPropertyValue(u"ControlBorder"_ustr) >>= nBorderStyle;
+    CPPUNIT_ASSERT_EQUAL(sal_uInt16(0), nBorderStyle);
+}
+
 CPPUNIT_TEST_FIXTURE(XmloffStyleTest, testMCGR_OldToNew)
 {
     // The file contains a shape with linear gradient fill from red #ff0000 to yellow #ffff00,
@@ -348,17 +337,17 @@ CPPUNIT_TEST_FIXTURE(XmloffStyleTest, testMCGR_OldToNew)
     xmlDocUniquePtr pXmlDoc = parseExport(u"styles.xml"_ustr);
     OString sPath
         = "/office:document-styles/office:styles/draw:gradient[@draw:name='red2yellow']"_ostr;
-    assertXPath(pXmlDoc, sPath, "start-color"_ostr, u"#ff0000"_ustr);
-    assertXPath(pXmlDoc, sPath, "end-color"_ostr, u"#ffff00"_ustr);
+    assertXPath(pXmlDoc, sPath, "start-color", u"#ff0000");
+    assertXPath(pXmlDoc, sPath, "end-color", u"#ffff00");
 
     // And it must have the new 'gradient-stop' elements.
     // The prefix 'loext' needs to be adapted, when the element is available in ODF strict.
-    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[1]", "offset"_ostr, u"0"_ustr);
-    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[1]", "color-type"_ostr, u"rgb"_ustr);
-    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[1]", "color-value"_ostr, u"#ff0000"_ustr);
-    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[2]", "offset"_ostr, u"1"_ustr);
-    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[2]", "color-type"_ostr, u"rgb"_ustr);
-    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[2]", "color-value"_ostr, u"#ffff00"_ustr);
+    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[1]", "offset", u"0");
+    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[1]", "color-type", u"rgb");
+    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[1]", "color-value", u"#ff0000");
+    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[2]", "offset", u"1");
+    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[2]", "color-type", u"rgb");
+    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[2]", "color-value", u"#ffff00");
 
     // Examine reloaded file
     uno::Reference<drawing::XShape> xShape(getShape(0));
@@ -401,23 +390,23 @@ CPPUNIT_TEST_FIXTURE(XmloffStyleTest, testMCGR_OldToNew_opacity)
     // For compatibility the file should still have the old attributes.
     xmlDocUniquePtr pXmlDoc = parseExport(u"styles.xml"_ustr);
     OString sPath = "/office:document-styles/office:styles/draw:opacity"_ostr;
-    assertXPath(pXmlDoc, sPath, "start"_ostr, u"10%"_ustr); // UI 90% transparency
-    assertXPath(pXmlDoc, sPath, "end"_ostr, u"100%"_ustr); // UI 0% transparency
-    assertXPath(pXmlDoc, sPath, "border"_ostr, u"20%"_ustr);
-    assertXPath(pXmlDoc, sPath, "cx"_ostr, u"50%"_ustr);
-    assertXPath(pXmlDoc, sPath, "cy"_ostr, u"50%"_ustr);
-    assertXPath(pXmlDoc, sPath, "style"_ostr, u"radial"_ustr);
+    assertXPath(pXmlDoc, sPath, "start", u"10%"); // UI 90% transparency
+    assertXPath(pXmlDoc, sPath, "end", u"100%"); // UI 0% transparency
+    assertXPath(pXmlDoc, sPath, "border", u"20%");
+    assertXPath(pXmlDoc, sPath, "cx", u"50%");
+    assertXPath(pXmlDoc, sPath, "cy", u"50%");
+    assertXPath(pXmlDoc, sPath, "style", u"radial");
 
     // And it must have the new 'opacity-stop' elements.
     // The prefix 'loext' needs to be adapted, when the element is available in ODF strict.
     OString sFirstStop = sPath + "/loext:opacity-stop[1]";
-    assertXPath(pXmlDoc, sFirstStop, "offset"_ostr, u"0"_ustr);
+    assertXPath(pXmlDoc, sFirstStop, "offset", u"0");
     // Because of converting through color, the grade of opacity is not exact "0.1"
     double fOpacity = getXPathContent(pXmlDoc, sFirstStop + "/@svg:stop-opacity").toDouble();
     CPPUNIT_ASSERT_DOUBLES_EQUAL(0.1, fOpacity, 0.002);
 
-    assertXPath(pXmlDoc, sPath + "/loext:opacity-stop[2]", "offset"_ostr, u"1"_ustr);
-    assertXPath(pXmlDoc, sPath + "/loext:opacity-stop[2]", "stop-opacity"_ostr, u"1"_ustr);
+    assertXPath(pXmlDoc, sPath + "/loext:opacity-stop[2]", "offset", u"1");
+    assertXPath(pXmlDoc, sPath + "/loext:opacity-stop[2]", "stop-opacity", u"1");
 
     // Examine reloaded file
     uno::Reference<drawing::XShape> xShape(getShape(0));
@@ -462,25 +451,25 @@ CPPUNIT_TEST_FIXTURE(XmloffStyleTest, testMCGR_threeStops)
     xmlDocUniquePtr pXmlDoc = parseExport(u"styles.xml"_ustr);
     OString sPath
         = "/office:document-styles/office:styles/draw:gradient[@draw:name='threeStops']"_ostr;
-    assertXPath(pXmlDoc, sPath, "start-color"_ostr, u"#ff0000"_ustr);
-    assertXPath(pXmlDoc, sPath, "end-color"_ostr, u"#ffff00"_ustr);
-    assertXPath(pXmlDoc, sPath, "style"_ostr, u"square"_ustr);
-    assertXPath(pXmlDoc, sPath, "cx"_ostr, u"0%"_ustr);
-    assertXPath(pXmlDoc, sPath, "cy"_ostr, u"50%"_ustr);
-    assertXPath(pXmlDoc, sPath, "angle"_ostr, u"45deg"_ustr);
-    assertXPath(pXmlDoc, sPath, "border"_ostr, u"10%"_ustr);
+    assertXPath(pXmlDoc, sPath, "start-color", u"#ff0000");
+    assertXPath(pXmlDoc, sPath, "end-color", u"#ffff00");
+    assertXPath(pXmlDoc, sPath, "style", u"square");
+    assertXPath(pXmlDoc, sPath, "cx", u"0%");
+    assertXPath(pXmlDoc, sPath, "cy", u"50%");
+    assertXPath(pXmlDoc, sPath, "angle", u"45deg");
+    assertXPath(pXmlDoc, sPath, "border", u"10%");
 
     // And it must have the new 'gradient-stop' elements.
     // The prefix 'loext' needs to be adapted, when the element is available in ODF strict.
-    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[1]", "offset"_ostr, u"0"_ustr);
-    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[1]", "color-type"_ostr, u"rgb"_ustr);
-    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[1]", "color-value"_ostr, u"#ff0000"_ustr);
-    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[2]", "offset"_ostr, u"0.3"_ustr);
-    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[2]", "color-type"_ostr, u"rgb"_ustr);
-    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[2]", "color-value"_ostr, u"#0099bb"_ustr);
-    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[3]", "offset"_ostr, u"1"_ustr);
-    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[3]", "color-type"_ostr, u"rgb"_ustr);
-    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[3]", "color-value"_ostr, u"#ffff00"_ustr);
+    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[1]", "offset", u"0");
+    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[1]", "color-type", u"rgb");
+    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[1]", "color-value", u"#ff0000");
+    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[2]", "offset", u"0.3");
+    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[2]", "color-type", u"rgb");
+    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[2]", "color-value", u"#0099bb");
+    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[3]", "offset", u"1");
+    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[3]", "color-type", u"rgb");
+    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[3]", "color-value", u"#ffff00");
 
     // Examine reloaded file
     uno::Reference<drawing::XShape> xShape(getShape(0));
@@ -522,6 +511,8 @@ CPPUNIT_TEST_FIXTURE(XmloffStyleTest, testMCGR_threeStops)
 
 CPPUNIT_TEST_FIXTURE(XmloffStyleTest, testBorderRestoration)
 {
+    Resetter resetter([]() { SetODFDefaultVersion(SvtSaveOptions::ODFVER_LATEST); });
+
     // Load document. It has a shape with color gradient build from color stop yellow at offset 0.5
     // and color stop red at offset 1.0. For better backward compatibility such gradient has to be
     // exported to ODF with a border of 50%.
@@ -530,36 +521,35 @@ CPPUNIT_TEST_FIXTURE(XmloffStyleTest, testBorderRestoration)
     loadFromFile(u"MCGR_Border_restoration.pptx");
 
     // Backup original ODF default version
-    const SvtSaveOptions::ODFDefaultVersion nCurrentODFVersion(GetODFDefaultVersion());
 
-    // Save to ODF_LATEST which is currently ODF 1.3 extended. Make sure gradient-stop elements have
+    // Save to LATEST; that is extended. Make sure gradient-stop elements have
     // offsets 0 and 1, and border is written as 50%.
-    SetODFDefaultVersion(SvtSaveOptions::ODFDefaultVersion::ODFVER_LATEST);
     save(u"impress8"_ustr);
     xmlDocUniquePtr pXmlDoc = parseExport(u"styles.xml"_ustr);
     OString sPath
         = "/office:document-styles/office:styles/draw:gradient[@draw:name='Gradient_20_1']"_ostr;
-    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[2]", "color-value"_ostr, u"#ff0000"_ustr);
-    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[2]", "offset"_ostr, u"1"_ustr);
-    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[1]", "color-value"_ostr, u"#ffff00"_ustr);
-    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[1]", "offset"_ostr, u"0"_ustr);
-    assertXPath(pXmlDoc, sPath, "border"_ostr, u"50%"_ustr);
+    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[2]", "color-value", u"#ff0000");
+    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[2]", "offset", u"1");
+    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[1]", "color-value", u"#ffff00");
+    assertXPath(pXmlDoc, sPath + "/loext:gradient-stop[1]", "offset", u"0");
+    assertXPath(pXmlDoc, sPath, "border", u"50%");
 
     // Save to ODF 1.3 strict and make sure border, start-color and end-color are suitable set.
     SetODFDefaultVersion(SvtSaveOptions::ODFDefaultVersion::ODFVER_013);
+    // As of Nov 2024, validating against a version other than LATEST is not implemented.
+    skipValidation();
     save(u"impress8"_ustr);
     pXmlDoc = parseExport(u"styles.xml"_ustr);
     assertXPath(pXmlDoc, sPath + "/loext:gradient-stop", 0);
-    assertXPath(pXmlDoc, sPath, "start-color"_ostr, u"#ffff00"_ustr);
-    assertXPath(pXmlDoc, sPath, "end-color"_ostr, u"#ff0000"_ustr);
-    assertXPath(pXmlDoc, sPath, "border"_ostr, u"50%"_ustr);
-
-    // Set back to original ODF default version.
-    SetODFDefaultVersion(nCurrentODFVersion);
+    assertXPath(pXmlDoc, sPath, "start-color", u"#ffff00");
+    assertXPath(pXmlDoc, sPath, "end-color", u"#ff0000");
+    assertXPath(pXmlDoc, sPath, "border", u"50%");
 }
 
 CPPUNIT_TEST_FIXTURE(XmloffStyleTest, testTransparencyBorderRestoration)
 {
+    Resetter resetter([]() { SetODFDefaultVersion(SvtSaveOptions::ODFVER_LATEST); });
+
     // Load document. It has a shape with transparency gradient build from transparency 100% at
     // offset 0, transparency 100% at offset 0.4 and transparency 10% at offset 1.0. For better
     // backward compatibility such gradient is exported with a border of 40% in the transparency
@@ -567,32 +557,27 @@ CPPUNIT_TEST_FIXTURE(XmloffStyleTest, testTransparencyBorderRestoration)
     // When transparency gradient-stops are integrated in ODF strict, the test needs to be adapted.
     loadFromFile(u"MCGR_TransparencyBorder_restoration.pptx");
 
-    // Backup original ODF default version
-    const SvtSaveOptions::ODFDefaultVersion nCurrentODFVersion(GetODFDefaultVersion());
-
-    // Save to ODF_LATEST which is currently ODF 1.3 extended. Make sure transparency gradient-stop
+    // Save to LATEST, that is extended. Make sure transparency gradient-stop
     //elements are written with offset 0 and 1, and border is written as 40%.
-    SetODFDefaultVersion(SvtSaveOptions::ODFDefaultVersion::ODFVER_LATEST);
     save(u"impress8"_ustr);
     xmlDocUniquePtr pXmlDoc = parseExport(u"styles.xml"_ustr);
     OString sPath = "/office:document-styles/office:styles/draw:opacity[1]"_ostr;
-    assertXPath(pXmlDoc, sPath + "/loext:opacity-stop[2]", "stop-opacity"_ostr, u"0.9"_ustr);
-    assertXPath(pXmlDoc, sPath + "/loext:opacity-stop[2]", "offset"_ostr, u"1"_ustr);
-    assertXPath(pXmlDoc, sPath + "/loext:opacity-stop[1]", "stop-opacity"_ostr, u"0"_ustr);
-    assertXPath(pXmlDoc, sPath + "/loext:opacity-stop[1]", "offset"_ostr, u"0"_ustr);
-    assertXPath(pXmlDoc, sPath, "border"_ostr, u"40%"_ustr);
-
+    assertXPath(pXmlDoc, sPath + "/loext:opacity-stop[2]", "stop-opacity", u"0.9");
+    assertXPath(pXmlDoc, sPath + "/loext:opacity-stop[2]", "offset", u"1");
+    assertXPath(pXmlDoc, sPath + "/loext:opacity-stop[1]", "stop-opacity", u"0");
+    assertXPath(pXmlDoc, sPath + "/loext:opacity-stop[1]", "offset", u"0");
+    assertXPath(pXmlDoc, sPath, "border", u"40%");
+    // As of Nov 2024, validating against a version other than LATEST is not implemented.
+    skipValidation();
     // Save to ODF 1.3 strict and make sure border, start and end opacity are suitable set.
     SetODFDefaultVersion(SvtSaveOptions::ODFDefaultVersion::ODFVER_013);
+
     save(u"impress8"_ustr);
     pXmlDoc = parseExport(u"styles.xml"_ustr);
     assertXPath(pXmlDoc, sPath + "/loext:opacity-stop", 0);
-    assertXPath(pXmlDoc, sPath, "start"_ostr, u"0%"_ustr);
-    assertXPath(pXmlDoc, sPath, "end"_ostr, u"90%"_ustr);
-    assertXPath(pXmlDoc, sPath, "border"_ostr, u"40%"_ustr);
-
-    // Set back to original ODF default version.
-    SetODFDefaultVersion(nCurrentODFVersion);
+    assertXPath(pXmlDoc, sPath, "start", u"0%");
+    assertXPath(pXmlDoc, sPath, "end", u"90%");
+    assertXPath(pXmlDoc, sPath, "border", u"40%");
 }
 
 CPPUNIT_TEST_FIXTURE(XmloffStyleTest, testAxialGradientCompatible)
