@@ -932,8 +932,8 @@ bool XMLChartImportPropertyMapper::handleSpecialItem(
                 {
                     // convert from degrees (double) to 100th degrees (integer)
                     double fVal;
-                    ::sax::Converter::convertDouble( fVal, rValue );
-                    nValue = static_cast<sal_Int32>( fVal * 100.0 );
+                    ::sax::Converter::convertAngle(fVal, rValue);
+                    nValue = static_cast<sal_Int32>(basegfx::fround(fVal * 100));
                     rProperty.maValue <<= nValue;
                 }
                 break;
@@ -1050,7 +1050,9 @@ bool XMLChartImportPropertyMapper::handleSpecialItem(
     return bRet;
 }
 
-void XMLChartImportPropertyMapper::finished( ::std::vector< XMLPropertyState >& /*rProperties*/, sal_Int32 /*nStartIndex*/, sal_Int32 /*nEndIndex*/ ) const
+void XMLChartImportPropertyMapper::finished(std::vector<XMLPropertyState>& /*rProperties*/,
+                                            sal_Int32 /*nStartIndex*/, sal_Int32 /*nEndIndex*/,
+                                            const sal_uInt32 /*nPropMap*/) const
 {
 }
 
