@@ -29,7 +29,6 @@
 #include <com/sun/star/beans/XPropertySet.hpp>
 #include <xmloff/xmlimp.hxx>
 #include <xmloff/xmlprmap.hxx>
-#include <memory>
 
 #define XML_LINE_LEFT 0
 #define XML_LINE_RIGHT 1
@@ -86,9 +85,11 @@ bool PageMasterImportPropertyMapper::handleSpecialItem(
 }
 
 
-void PageMasterImportPropertyMapper::finished(std::vector< XMLPropertyState >& rProperties, sal_Int32 nStartIndex, sal_Int32 nEndIndex ) const
+void PageMasterImportPropertyMapper::finished(std::vector<XMLPropertyState>& rProperties,
+                                              sal_Int32 nStartIndex, sal_Int32 nEndIndex,
+                                              const sal_uInt32 nPropType) const
 {
-    SvXMLImportPropertyMapper::finished(rProperties, nStartIndex, nEndIndex);
+    SvXMLImportPropertyMapper::finished(rProperties, nStartIndex, nEndIndex, nPropType);
     XMLPropertyState* pAllPaddingProperty = nullptr;
     XMLPropertyState* pPadding[4] = { nullptr, nullptr, nullptr, nullptr };
     XMLPropertyState* pNewPadding[4] = { nullptr, nullptr, nullptr, nullptr };
@@ -397,16 +398,16 @@ void PageMasterImportPropertyMapper::finished(std::vector< XMLPropertyState >& r
 
         bool bGutterAtTop{};
         uno::Reference<lang::XServiceInfo> xSI(GetImport().GetModel(), uno::UNO_QUERY);
-        if (xSI.is() && xSI->supportsService("com.sun.star.text.TextDocument"))
+        if (xSI.is() && xSI->supportsService(u"com.sun.star.text.TextDocument"_ustr))
         {
             uno::Reference<lang::XMultiServiceFactory> xFac(GetImport().GetModel(), uno::UNO_QUERY);
             if (xFac.is())
             {
                 uno::Reference<beans::XPropertySet> xProps(
-                    xFac->createInstance("com.sun.star.document.Settings"), uno::UNO_QUERY);
+                    xFac->createInstance(u"com.sun.star.document.Settings"_ustr), uno::UNO_QUERY);
                 if (xProps.is())
                 {
-                    xProps->getPropertyValue("GutterAtTop") >>= bGutterAtTop;
+                    xProps->getPropertyValue(u"GutterAtTop"_ustr) >>= bGutterAtTop;
                 }
             }
         }
